// This file has been generated by Py++.

#include "boost/python.hpp"
#include "__ctypes_integration.pypp.hpp"
#include "opencv_headers.hpp"
#include "__dummy_struct.pypp.hpp"

namespace bp = boost::python;

static inline ::cv::Vec<short, 2> cvt_Vec2b_Vec2s(::cv::Vec<unsigned char, 2> const &inst)
{
    return inst.operator ::cv::Vec<short, 2>();
}

static inline ::cv::Vec<unsigned short, 2> cvt_Vec2b_Vec2w(::cv::Vec<unsigned char, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 2>();
}

static inline ::cv::Vec<int, 2> cvt_Vec2b_Vec2i(::cv::Vec<unsigned char, 2> const &inst)
{
    return inst.operator ::cv::Vec<int, 2>();
}

static inline ::cv::Vec<float, 2> cvt_Vec2b_Vec2f(::cv::Vec<unsigned char, 2> const &inst)
{
    return inst.operator ::cv::Vec<float, 2>();
}

static inline ::cv::Vec<double, 2> cvt_Vec2b_Vec2d(::cv::Vec<unsigned char, 2> const &inst)
{
    return inst.operator ::cv::Vec<double, 2>();
}

static inline ::cv::Vec<unsigned char, 2> cvt_Vec2s_Vec2b(::cv::Vec<short, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 2>();
}

static inline ::cv::Vec<unsigned short, 2> cvt_Vec2s_Vec2w(::cv::Vec<short, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 2>();
}

static inline ::cv::Vec<int, 2> cvt_Vec2s_Vec2i(::cv::Vec<short, 2> const &inst)
{
    return inst.operator ::cv::Vec<int, 2>();
}

static inline ::cv::Vec<float, 2> cvt_Vec2s_Vec2f(::cv::Vec<short, 2> const &inst)
{
    return inst.operator ::cv::Vec<float, 2>();
}

static inline ::cv::Vec<double, 2> cvt_Vec2s_Vec2d(::cv::Vec<short, 2> const &inst)
{
    return inst.operator ::cv::Vec<double, 2>();
}

static inline ::cv::Vec<unsigned char, 2> cvt_Vec2w_Vec2b(::cv::Vec<unsigned short, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 2>();
}

static inline ::cv::Vec<short, 2> cvt_Vec2w_Vec2s(::cv::Vec<unsigned short, 2> const &inst)
{
    return inst.operator ::cv::Vec<short, 2>();
}

static inline ::cv::Vec<int, 2> cvt_Vec2w_Vec2i(::cv::Vec<unsigned short, 2> const &inst)
{
    return inst.operator ::cv::Vec<int, 2>();
}

static inline ::cv::Vec<float, 2> cvt_Vec2w_Vec2f(::cv::Vec<unsigned short, 2> const &inst)
{
    return inst.operator ::cv::Vec<float, 2>();
}

static inline ::cv::Vec<double, 2> cvt_Vec2w_Vec2d(::cv::Vec<unsigned short, 2> const &inst)
{
    return inst.operator ::cv::Vec<double, 2>();
}

static inline ::cv::Vec<unsigned char, 2> cvt_Vec2i_Vec2b(::cv::Vec<int, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 2>();
}

static inline ::cv::Vec<short, 2> cvt_Vec2i_Vec2s(::cv::Vec<int, 2> const &inst)
{
    return inst.operator ::cv::Vec<short, 2>();
}

static inline ::cv::Vec<unsigned short, 2> cvt_Vec2i_Vec2w(::cv::Vec<int, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 2>();
}

static inline ::cv::Vec<float, 2> cvt_Vec2i_Vec2f(::cv::Vec<int, 2> const &inst)
{
    return inst.operator ::cv::Vec<float, 2>();
}

static inline ::cv::Vec<double, 2> cvt_Vec2i_Vec2d(::cv::Vec<int, 2> const &inst)
{
    return inst.operator ::cv::Vec<double, 2>();
}

static inline ::cv::Vec<unsigned char, 2> cvt_Vec2f_Vec2b(::cv::Vec<float, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 2>();
}

static inline ::cv::Vec<short, 2> cvt_Vec2f_Vec2s(::cv::Vec<float, 2> const &inst)
{
    return inst.operator ::cv::Vec<short, 2>();
}

static inline ::cv::Vec<unsigned short, 2> cvt_Vec2f_Vec2w(::cv::Vec<float, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 2>();
}

static inline ::cv::Vec<int, 2> cvt_Vec2f_Vec2i(::cv::Vec<float, 2> const &inst)
{
    return inst.operator ::cv::Vec<int, 2>();
}

static inline ::cv::Vec<double, 2> cvt_Vec2f_Vec2d(::cv::Vec<float, 2> const &inst)
{
    return inst.operator ::cv::Vec<double, 2>();
}

static inline ::cv::Vec<unsigned char, 2> cvt_Vec2d_Vec2b(::cv::Vec<double, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 2>();
}

static inline ::cv::Vec<short, 2> cvt_Vec2d_Vec2s(::cv::Vec<double, 2> const &inst)
{
    return inst.operator ::cv::Vec<short, 2>();
}

static inline ::cv::Vec<unsigned short, 2> cvt_Vec2d_Vec2w(::cv::Vec<double, 2> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 2>();
}

static inline ::cv::Vec<int, 2> cvt_Vec2d_Vec2i(::cv::Vec<double, 2> const &inst)
{
    return inst.operator ::cv::Vec<int, 2>();
}

static inline ::cv::Vec<float, 2> cvt_Vec2d_Vec2f(::cv::Vec<double, 2> const &inst)
{
    return inst.operator ::cv::Vec<float, 2>();
}

static inline ::cv::Vec<short, 3> cvt_Vec3b_Vec3s(::cv::Vec<unsigned char, 3> const &inst)
{
    return inst.operator ::cv::Vec<short, 3>();
}

static inline ::cv::Vec<unsigned short, 3> cvt_Vec3b_Vec3w(::cv::Vec<unsigned char, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 3>();
}

static inline ::cv::Vec<int, 3> cvt_Vec3b_Vec3i(::cv::Vec<unsigned char, 3> const &inst)
{
    return inst.operator ::cv::Vec<int, 3>();
}

static inline ::cv::Vec<float, 3> cvt_Vec3b_Vec3f(::cv::Vec<unsigned char, 3> const &inst)
{
    return inst.operator ::cv::Vec<float, 3>();
}

static inline ::cv::Vec<double, 3> cvt_Vec3b_Vec3d(::cv::Vec<unsigned char, 3> const &inst)
{
    return inst.operator ::cv::Vec<double, 3>();
}

static inline ::cv::Vec<unsigned char, 3> cvt_Vec3s_Vec3b(::cv::Vec<short, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 3>();
}

static inline ::cv::Vec<unsigned short, 3> cvt_Vec3s_Vec3w(::cv::Vec<short, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 3>();
}

static inline ::cv::Vec<int, 3> cvt_Vec3s_Vec3i(::cv::Vec<short, 3> const &inst)
{
    return inst.operator ::cv::Vec<int, 3>();
}

static inline ::cv::Vec<float, 3> cvt_Vec3s_Vec3f(::cv::Vec<short, 3> const &inst)
{
    return inst.operator ::cv::Vec<float, 3>();
}

static inline ::cv::Vec<double, 3> cvt_Vec3s_Vec3d(::cv::Vec<short, 3> const &inst)
{
    return inst.operator ::cv::Vec<double, 3>();
}

static inline ::cv::Vec<unsigned char, 3> cvt_Vec3w_Vec3b(::cv::Vec<unsigned short, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 3>();
}

static inline ::cv::Vec<short, 3> cvt_Vec3w_Vec3s(::cv::Vec<unsigned short, 3> const &inst)
{
    return inst.operator ::cv::Vec<short, 3>();
}

static inline ::cv::Vec<int, 3> cvt_Vec3w_Vec3i(::cv::Vec<unsigned short, 3> const &inst)
{
    return inst.operator ::cv::Vec<int, 3>();
}

static inline ::cv::Vec<float, 3> cvt_Vec3w_Vec3f(::cv::Vec<unsigned short, 3> const &inst)
{
    return inst.operator ::cv::Vec<float, 3>();
}

static inline ::cv::Vec<double, 3> cvt_Vec3w_Vec3d(::cv::Vec<unsigned short, 3> const &inst)
{
    return inst.operator ::cv::Vec<double, 3>();
}

static inline ::cv::Vec<unsigned char, 3> cvt_Vec3i_Vec3b(::cv::Vec<int, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 3>();
}

static inline ::cv::Vec<short, 3> cvt_Vec3i_Vec3s(::cv::Vec<int, 3> const &inst)
{
    return inst.operator ::cv::Vec<short, 3>();
}

static inline ::cv::Vec<unsigned short, 3> cvt_Vec3i_Vec3w(::cv::Vec<int, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 3>();
}

static inline ::cv::Vec<float, 3> cvt_Vec3i_Vec3f(::cv::Vec<int, 3> const &inst)
{
    return inst.operator ::cv::Vec<float, 3>();
}

static inline ::cv::Vec<double, 3> cvt_Vec3i_Vec3d(::cv::Vec<int, 3> const &inst)
{
    return inst.operator ::cv::Vec<double, 3>();
}

static inline ::cv::Vec<unsigned char, 3> cvt_Vec3f_Vec3b(::cv::Vec<float, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 3>();
}

static inline ::cv::Vec<short, 3> cvt_Vec3f_Vec3s(::cv::Vec<float, 3> const &inst)
{
    return inst.operator ::cv::Vec<short, 3>();
}

static inline ::cv::Vec<unsigned short, 3> cvt_Vec3f_Vec3w(::cv::Vec<float, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 3>();
}

static inline ::cv::Vec<int, 3> cvt_Vec3f_Vec3i(::cv::Vec<float, 3> const &inst)
{
    return inst.operator ::cv::Vec<int, 3>();
}

static inline ::cv::Vec<double, 3> cvt_Vec3f_Vec3d(::cv::Vec<float, 3> const &inst)
{
    return inst.operator ::cv::Vec<double, 3>();
}

static inline ::cv::Vec<unsigned char, 3> cvt_Vec3d_Vec3b(::cv::Vec<double, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 3>();
}

static inline ::cv::Vec<short, 3> cvt_Vec3d_Vec3s(::cv::Vec<double, 3> const &inst)
{
    return inst.operator ::cv::Vec<short, 3>();
}

static inline ::cv::Vec<unsigned short, 3> cvt_Vec3d_Vec3w(::cv::Vec<double, 3> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 3>();
}

static inline ::cv::Vec<int, 3> cvt_Vec3d_Vec3i(::cv::Vec<double, 3> const &inst)
{
    return inst.operator ::cv::Vec<int, 3>();
}

static inline ::cv::Vec<float, 3> cvt_Vec3d_Vec3f(::cv::Vec<double, 3> const &inst)
{
    return inst.operator ::cv::Vec<float, 3>();
}

static inline ::cv::Vec<short, 4> cvt_Vec4b_Vec4s(::cv::Vec<unsigned char, 4> const &inst)
{
    return inst.operator ::cv::Vec<short, 4>();
}

static inline ::cv::Vec<unsigned short, 4> cvt_Vec4b_Vec4w(::cv::Vec<unsigned char, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 4>();
}

static inline ::cv::Vec<int, 4> cvt_Vec4b_Vec4i(::cv::Vec<unsigned char, 4> const &inst)
{
    return inst.operator ::cv::Vec<int, 4>();
}

static inline ::cv::Vec<float, 4> cvt_Vec4b_Vec4f(::cv::Vec<unsigned char, 4> const &inst)
{
    return inst.operator ::cv::Vec<float, 4>();
}

static inline ::cv::Vec<double, 4> cvt_Vec4b_Vec4d(::cv::Vec<unsigned char, 4> const &inst)
{
    return inst.operator ::cv::Vec<double, 4>();
}

static inline ::cv::Vec<unsigned char, 4> cvt_Vec4s_Vec4b(::cv::Vec<short, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 4>();
}

static inline ::cv::Vec<unsigned short, 4> cvt_Vec4s_Vec4w(::cv::Vec<short, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 4>();
}

static inline ::cv::Vec<int, 4> cvt_Vec4s_Vec4i(::cv::Vec<short, 4> const &inst)
{
    return inst.operator ::cv::Vec<int, 4>();
}

static inline ::cv::Vec<float, 4> cvt_Vec4s_Vec4f(::cv::Vec<short, 4> const &inst)
{
    return inst.operator ::cv::Vec<float, 4>();
}

static inline ::cv::Vec<double, 4> cvt_Vec4s_Vec4d(::cv::Vec<short, 4> const &inst)
{
    return inst.operator ::cv::Vec<double, 4>();
}

static inline ::cv::Vec<unsigned char, 4> cvt_Vec4w_Vec4b(::cv::Vec<unsigned short, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 4>();
}

static inline ::cv::Vec<short, 4> cvt_Vec4w_Vec4s(::cv::Vec<unsigned short, 4> const &inst)
{
    return inst.operator ::cv::Vec<short, 4>();
}

static inline ::cv::Vec<int, 4> cvt_Vec4w_Vec4i(::cv::Vec<unsigned short, 4> const &inst)
{
    return inst.operator ::cv::Vec<int, 4>();
}

static inline ::cv::Vec<float, 4> cvt_Vec4w_Vec4f(::cv::Vec<unsigned short, 4> const &inst)
{
    return inst.operator ::cv::Vec<float, 4>();
}

static inline ::cv::Vec<double, 4> cvt_Vec4w_Vec4d(::cv::Vec<unsigned short, 4> const &inst)
{
    return inst.operator ::cv::Vec<double, 4>();
}

static inline ::cv::Vec<unsigned char, 4> cvt_Vec4i_Vec4b(::cv::Vec<int, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 4>();
}

static inline ::cv::Vec<short, 4> cvt_Vec4i_Vec4s(::cv::Vec<int, 4> const &inst)
{
    return inst.operator ::cv::Vec<short, 4>();
}

static inline ::cv::Vec<unsigned short, 4> cvt_Vec4i_Vec4w(::cv::Vec<int, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 4>();
}

static inline ::cv::Vec<float, 4> cvt_Vec4i_Vec4f(::cv::Vec<int, 4> const &inst)
{
    return inst.operator ::cv::Vec<float, 4>();
}

static inline ::cv::Vec<double, 4> cvt_Vec4i_Vec4d(::cv::Vec<int, 4> const &inst)
{
    return inst.operator ::cv::Vec<double, 4>();
}

static inline ::cv::Vec<unsigned char, 4> cvt_Vec4f_Vec4b(::cv::Vec<float, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 4>();
}

static inline ::cv::Vec<short, 4> cvt_Vec4f_Vec4s(::cv::Vec<float, 4> const &inst)
{
    return inst.operator ::cv::Vec<short, 4>();
}

static inline ::cv::Vec<unsigned short, 4> cvt_Vec4f_Vec4w(::cv::Vec<float, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 4>();
}

static inline ::cv::Vec<int, 4> cvt_Vec4f_Vec4i(::cv::Vec<float, 4> const &inst)
{
    return inst.operator ::cv::Vec<int, 4>();
}

static inline ::cv::Vec<double, 4> cvt_Vec4f_Vec4d(::cv::Vec<float, 4> const &inst)
{
    return inst.operator ::cv::Vec<double, 4>();
}

static inline ::cv::Vec<unsigned char, 4> cvt_Vec4d_Vec4b(::cv::Vec<double, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned char, 4>();
}

static inline ::cv::Vec<short, 4> cvt_Vec4d_Vec4s(::cv::Vec<double, 4> const &inst)
{
    return inst.operator ::cv::Vec<short, 4>();
}

static inline ::cv::Vec<unsigned short, 4> cvt_Vec4d_Vec4w(::cv::Vec<double, 4> const &inst)
{
    return inst.operator ::cv::Vec<unsigned short, 4>();
}

static inline ::cv::Vec<int, 4> cvt_Vec4d_Vec4i(::cv::Vec<double, 4> const &inst)
{
    return inst.operator ::cv::Vec<int, 4>();
}

static inline ::cv::Vec<float, 4> cvt_Vec4d_Vec4f(::cv::Vec<double, 4> const &inst)
{
    return inst.operator ::cv::Vec<float, 4>();
}

static inline ::cv::Vec<double, 6> cvt_Vec6f_Vec6d(::cv::Vec<float, 6> const &inst)
{
    return inst.operator ::cv::Vec<double, 6>();
}

static inline ::cv::Vec<float, 6> cvt_Vec6d_Vec6f(::cv::Vec<double, 6> const &inst)
{
    return inst.operator ::cv::Vec<float, 6>();
}

static inline ::cv::Complex<double> cvt_Complexf_Complexd(::cv::Complex<float> const &inst)
{
    return inst.operator ::cv::Complex<double>();
}

static inline ::cv::Complex<float> cvt_Complexd_Complexf(::cv::Complex<double> const &inst)
{
    return inst.operator ::cv::Complex<float>();
}

static inline ::cv::Point_<float> cvt_Point2i_Point2f(::cv::Point_<int> const &inst)
{
    return inst.operator ::cv::Point_<float>();
}

static inline ::cv::Point_<double> cvt_Point2i_Point2d(::cv::Point_<int> const &inst)
{
    return inst.operator ::cv::Point_<double>();
}

static inline ::cv::Point_<int> cvt_Point2f_Point2i(::cv::Point_<float> const &inst)
{
    return inst.operator ::cv::Point_<int>();
}

static inline ::cv::Point_<double> cvt_Point2f_Point2d(::cv::Point_<float> const &inst)
{
    return inst.operator ::cv::Point_<double>();
}

static inline ::cv::Point_<int> cvt_Point2d_Point2i(::cv::Point_<double> const &inst)
{
    return inst.operator ::cv::Point_<int>();
}

static inline ::cv::Point_<float> cvt_Point2d_Point2f(::cv::Point_<double> const &inst)
{
    return inst.operator ::cv::Point_<float>();
}

static inline ::cv::Point3_<float> cvt_Point3i_Point3f(::cv::Point3_<int> const &inst)
{
    return inst.operator ::cv::Point3_<float>();
}

static inline ::cv::Point3_<double> cvt_Point3i_Point3d(::cv::Point3_<int> const &inst)
{
    return inst.operator ::cv::Point3_<double>();
}

static inline ::cv::Point3_<int> cvt_Point3f_Point3i(::cv::Point3_<float> const &inst)
{
    return inst.operator ::cv::Point3_<int>();
}

static inline ::cv::Point3_<double> cvt_Point3f_Point3d(::cv::Point3_<float> const &inst)
{
    return inst.operator ::cv::Point3_<double>();
}

static inline ::cv::Point3_<int> cvt_Point3d_Point3i(::cv::Point3_<double> const &inst)
{
    return inst.operator ::cv::Point3_<int>();
}

static inline ::cv::Point3_<float> cvt_Point3d_Point3f(::cv::Point3_<double> const &inst)
{
    return inst.operator ::cv::Point3_<float>();
}

static inline ::cv::Size_<float> cvt_Size2i_Size2f(::cv::Size_<int> const &inst)
{
    return inst.operator ::cv::Size_<float>();
}

static inline ::cv::Size_<double> cvt_Size2i_Size2d(::cv::Size_<int> const &inst)
{
    return inst.operator ::cv::Size_<double>();
}

static inline ::cv::Size_<int> cvt_Size2f_Size2i(::cv::Size_<float> const &inst)
{
    return inst.operator ::cv::Size_<int>();
}

static inline ::cv::Size_<double> cvt_Size2f_Size2d(::cv::Size_<float> const &inst)
{
    return inst.operator ::cv::Size_<double>();
}

static inline ::cv::Size_<int> cvt_Size2d_Size2i(::cv::Size_<double> const &inst)
{
    return inst.operator ::cv::Size_<int>();
}

static inline ::cv::Size_<float> cvt_Size2d_Size2f(::cv::Size_<double> const &inst)
{
    return inst.operator ::cv::Size_<float>();
}

static inline ::cv::Rect_<float> cvt_Rect_Rectf(::cv::Rect_<int> const &inst)
{
    return inst.operator ::cv::Rect_<float>();
}

static inline ::cv::Rect_<double> cvt_Rect_Rectd(::cv::Rect_<int> const &inst)
{
    return inst.operator ::cv::Rect_<double>();
}

static inline ::cv::Rect_<int> cvt_Rectf_Rect(::cv::Rect_<float> const &inst)
{
    return inst.operator ::cv::Rect_<int>();
}

static inline ::cv::Rect_<double> cvt_Rectf_Rectd(::cv::Rect_<float> const &inst)
{
    return inst.operator ::cv::Rect_<double>();
}

static inline ::cv::Rect_<int> cvt_Rectd_Rect(::cv::Rect_<double> const &inst)
{
    return inst.operator ::cv::Rect_<int>();
}

static inline ::cv::Rect_<float> cvt_Rectd_Rectf(::cv::Rect_<double> const &inst)
{
    return inst.operator ::cv::Rect_<float>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat1b_Mat2b(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat1b_Mat3b(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat1b_Mat4b(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat1b_Mat1s(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat1b_Mat2s(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat1b_Mat3s(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat1b_Mat4s(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat1b_Mat1w(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat1b_Mat2w(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat1b_Mat3w(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat1b_Mat4w(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat1b_Mat1i(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat1b_Mat2i(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat1b_Mat3i(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat1b_Mat4i(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat1b_Mat1f(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat1b_Mat2f(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat1b_Mat3f(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat1b_Mat4f(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat1b_Mat1d(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat1b_Mat2d(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat1b_Mat3d(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat1b_Mat4d(::cv::Mat_<unsigned char> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat2b_Mat1b(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat2b_Mat3b(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat2b_Mat4b(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat2b_Mat1s(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat2b_Mat2s(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat2b_Mat3s(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat2b_Mat4s(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat2b_Mat1w(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat2b_Mat2w(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat2b_Mat3w(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat2b_Mat4w(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat2b_Mat1i(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat2b_Mat2i(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat2b_Mat3i(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat2b_Mat4i(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat2b_Mat1f(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat2b_Mat2f(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat2b_Mat3f(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat2b_Mat4f(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat2b_Mat1d(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat2b_Mat2d(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat2b_Mat3d(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat2b_Mat4d(::cv::Mat_<cv::Vec<unsigned char, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat3b_Mat1b(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat3b_Mat2b(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat3b_Mat4b(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat3b_Mat1s(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat3b_Mat2s(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat3b_Mat3s(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat3b_Mat4s(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat3b_Mat1w(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat3b_Mat2w(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat3b_Mat3w(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat3b_Mat4w(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat3b_Mat1i(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat3b_Mat2i(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat3b_Mat3i(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat3b_Mat4i(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat3b_Mat1f(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat3b_Mat2f(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat3b_Mat3f(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat3b_Mat4f(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat3b_Mat1d(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat3b_Mat2d(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat3b_Mat3d(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat3b_Mat4d(::cv::Mat_<cv::Vec<unsigned char, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat4b_Mat1b(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat4b_Mat2b(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat4b_Mat3b(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<short> cvt_Mat4b_Mat1s(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat4b_Mat2s(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat4b_Mat3s(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat4b_Mat4s(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat4b_Mat1w(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat4b_Mat2w(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat4b_Mat3w(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat4b_Mat4w(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat4b_Mat1i(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat4b_Mat2i(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat4b_Mat3i(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat4b_Mat4i(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat4b_Mat1f(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat4b_Mat2f(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat4b_Mat3f(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat4b_Mat4f(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat4b_Mat1d(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat4b_Mat2d(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat4b_Mat3d(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat4b_Mat4d(::cv::Mat_<cv::Vec<unsigned char, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat1s_Mat1b(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat1s_Mat2b(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat1s_Mat3b(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat1s_Mat4b(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat1s_Mat2s(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat1s_Mat3s(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat1s_Mat4s(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat1s_Mat1w(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat1s_Mat2w(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat1s_Mat3w(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat1s_Mat4w(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat1s_Mat1i(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat1s_Mat2i(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat1s_Mat3i(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat1s_Mat4i(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat1s_Mat1f(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat1s_Mat2f(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat1s_Mat3f(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat1s_Mat4f(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat1s_Mat1d(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat1s_Mat2d(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat1s_Mat3d(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat1s_Mat4d(::cv::Mat_<short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat2s_Mat1b(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat2s_Mat2b(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat2s_Mat3b(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat2s_Mat4b(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat2s_Mat1s(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat2s_Mat3s(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat2s_Mat4s(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat2s_Mat1w(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat2s_Mat2w(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat2s_Mat3w(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat2s_Mat4w(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat2s_Mat1i(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat2s_Mat2i(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat2s_Mat3i(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat2s_Mat4i(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat2s_Mat1f(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat2s_Mat2f(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat2s_Mat3f(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat2s_Mat4f(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat2s_Mat1d(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat2s_Mat2d(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat2s_Mat3d(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat2s_Mat4d(::cv::Mat_<cv::Vec<short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat3s_Mat1b(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat3s_Mat2b(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat3s_Mat3b(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat3s_Mat4b(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat3s_Mat1s(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat3s_Mat2s(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat3s_Mat4s(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat3s_Mat1w(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat3s_Mat2w(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat3s_Mat3w(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat3s_Mat4w(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat3s_Mat1i(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat3s_Mat2i(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat3s_Mat3i(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat3s_Mat4i(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat3s_Mat1f(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat3s_Mat2f(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat3s_Mat3f(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat3s_Mat4f(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat3s_Mat1d(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat3s_Mat2d(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat3s_Mat3d(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat3s_Mat4d(::cv::Mat_<cv::Vec<short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat4s_Mat1b(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat4s_Mat2b(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat4s_Mat3b(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat4s_Mat4b(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat4s_Mat1s(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat4s_Mat2s(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat4s_Mat3s(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat4s_Mat1w(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat4s_Mat2w(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat4s_Mat3w(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat4s_Mat4w(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat4s_Mat1i(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat4s_Mat2i(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat4s_Mat3i(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat4s_Mat4i(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat4s_Mat1f(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat4s_Mat2f(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat4s_Mat3f(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat4s_Mat4f(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat4s_Mat1d(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat4s_Mat2d(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat4s_Mat3d(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat4s_Mat4d(::cv::Mat_<cv::Vec<short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat1w_Mat1b(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat1w_Mat2b(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat1w_Mat3b(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat1w_Mat4b(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat1w_Mat1s(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat1w_Mat2s(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat1w_Mat3s(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat1w_Mat4s(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat1w_Mat2w(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat1w_Mat3w(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat1w_Mat4w(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat1w_Mat1i(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat1w_Mat2i(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat1w_Mat3i(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat1w_Mat4i(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat1w_Mat1f(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat1w_Mat2f(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat1w_Mat3f(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat1w_Mat4f(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat1w_Mat1d(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat1w_Mat2d(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat1w_Mat3d(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat1w_Mat4d(::cv::Mat_<unsigned short> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat2w_Mat1b(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat2w_Mat2b(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat2w_Mat3b(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat2w_Mat4b(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat2w_Mat1s(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat2w_Mat2s(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat2w_Mat3s(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat2w_Mat4s(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat2w_Mat1w(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat2w_Mat3w(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat2w_Mat4w(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat2w_Mat1i(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat2w_Mat2i(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat2w_Mat3i(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat2w_Mat4i(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat2w_Mat1f(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat2w_Mat2f(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat2w_Mat3f(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat2w_Mat4f(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat2w_Mat1d(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat2w_Mat2d(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat2w_Mat3d(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat2w_Mat4d(::cv::Mat_<cv::Vec<unsigned short, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat3w_Mat1b(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat3w_Mat2b(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat3w_Mat3b(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat3w_Mat4b(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat3w_Mat1s(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat3w_Mat2s(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat3w_Mat3s(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat3w_Mat4s(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat3w_Mat1w(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat3w_Mat2w(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat3w_Mat4w(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat3w_Mat1i(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat3w_Mat2i(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat3w_Mat3i(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat3w_Mat4i(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat3w_Mat1f(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat3w_Mat2f(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat3w_Mat3f(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat3w_Mat4f(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat3w_Mat1d(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat3w_Mat2d(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat3w_Mat3d(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat3w_Mat4d(::cv::Mat_<cv::Vec<unsigned short, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat4w_Mat1b(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat4w_Mat2b(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat4w_Mat3b(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat4w_Mat4b(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat4w_Mat1s(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat4w_Mat2s(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat4w_Mat3s(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat4w_Mat4s(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat4w_Mat1w(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat4w_Mat2w(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat4w_Mat3w(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<int> cvt_Mat4w_Mat1i(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat4w_Mat2i(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat4w_Mat3i(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat4w_Mat4i(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat4w_Mat1f(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat4w_Mat2f(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat4w_Mat3f(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat4w_Mat4f(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat4w_Mat1d(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat4w_Mat2d(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat4w_Mat3d(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat4w_Mat4d(::cv::Mat_<cv::Vec<unsigned short, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat1i_Mat1b(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat1i_Mat2b(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat1i_Mat3b(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat1i_Mat4b(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat1i_Mat1s(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat1i_Mat2s(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat1i_Mat3s(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat1i_Mat4s(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat1i_Mat1w(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat1i_Mat2w(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat1i_Mat3w(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat1i_Mat4w(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat1i_Mat2i(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat1i_Mat3i(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat1i_Mat4i(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat1i_Mat1f(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat1i_Mat2f(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat1i_Mat3f(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat1i_Mat4f(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat1i_Mat1d(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat1i_Mat2d(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat1i_Mat3d(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat1i_Mat4d(::cv::Mat_<int> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat2i_Mat1b(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat2i_Mat2b(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat2i_Mat3b(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat2i_Mat4b(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat2i_Mat1s(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat2i_Mat2s(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat2i_Mat3s(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat2i_Mat4s(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat2i_Mat1w(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat2i_Mat2w(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat2i_Mat3w(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat2i_Mat4w(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat2i_Mat1i(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat2i_Mat3i(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat2i_Mat4i(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat2i_Mat1f(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat2i_Mat2f(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat2i_Mat3f(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat2i_Mat4f(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat2i_Mat1d(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat2i_Mat2d(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat2i_Mat3d(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat2i_Mat4d(::cv::Mat_<cv::Vec<int, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat3i_Mat1b(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat3i_Mat2b(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat3i_Mat3b(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat3i_Mat4b(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat3i_Mat1s(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat3i_Mat2s(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat3i_Mat3s(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat3i_Mat4s(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat3i_Mat1w(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat3i_Mat2w(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat3i_Mat3w(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat3i_Mat4w(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat3i_Mat1i(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat3i_Mat2i(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat3i_Mat4i(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat3i_Mat1f(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat3i_Mat2f(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat3i_Mat3f(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat3i_Mat4f(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat3i_Mat1d(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat3i_Mat2d(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat3i_Mat3d(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat3i_Mat4d(::cv::Mat_<cv::Vec<int, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat4i_Mat1b(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat4i_Mat2b(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat4i_Mat3b(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat4i_Mat4b(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat4i_Mat1s(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat4i_Mat2s(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat4i_Mat3s(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat4i_Mat4s(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat4i_Mat1w(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat4i_Mat2w(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat4i_Mat3w(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat4i_Mat4w(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat4i_Mat1i(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat4i_Mat2i(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat4i_Mat3i(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<float> cvt_Mat4i_Mat1f(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat4i_Mat2f(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat4i_Mat3f(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat4i_Mat4f(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat4i_Mat1d(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat4i_Mat2d(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat4i_Mat3d(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat4i_Mat4d(::cv::Mat_<cv::Vec<int, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat1f_Mat1b(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat1f_Mat2b(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat1f_Mat3b(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat1f_Mat4b(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat1f_Mat1s(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat1f_Mat2s(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat1f_Mat3s(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat1f_Mat4s(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat1f_Mat1w(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat1f_Mat2w(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat1f_Mat3w(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat1f_Mat4w(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat1f_Mat1i(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat1f_Mat2i(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat1f_Mat3i(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat1f_Mat4i(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat1f_Mat2f(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat1f_Mat3f(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat1f_Mat4f(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat1f_Mat1d(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat1f_Mat2d(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat1f_Mat3d(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat1f_Mat4d(::cv::Mat_<float> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat2f_Mat1b(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat2f_Mat2b(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat2f_Mat3b(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat2f_Mat4b(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat2f_Mat1s(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat2f_Mat2s(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat2f_Mat3s(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat2f_Mat4s(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat2f_Mat1w(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat2f_Mat2w(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat2f_Mat3w(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat2f_Mat4w(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat2f_Mat1i(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat2f_Mat2i(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat2f_Mat3i(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat2f_Mat4i(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat2f_Mat1f(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat2f_Mat3f(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat2f_Mat4f(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat2f_Mat1d(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat2f_Mat2d(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat2f_Mat3d(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat2f_Mat4d(::cv::Mat_<cv::Vec<float, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat3f_Mat1b(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat3f_Mat2b(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat3f_Mat3b(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat3f_Mat4b(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat3f_Mat1s(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat3f_Mat2s(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat3f_Mat3s(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat3f_Mat4s(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat3f_Mat1w(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat3f_Mat2w(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat3f_Mat3w(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat3f_Mat4w(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat3f_Mat1i(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat3f_Mat2i(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat3f_Mat3i(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat3f_Mat4i(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat3f_Mat1f(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat3f_Mat2f(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat3f_Mat4f(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat3f_Mat1d(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat3f_Mat2d(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat3f_Mat3d(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat3f_Mat4d(::cv::Mat_<cv::Vec<float, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat4f_Mat1b(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat4f_Mat2b(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat4f_Mat3b(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat4f_Mat4b(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat4f_Mat1s(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat4f_Mat2s(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat4f_Mat3s(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat4f_Mat4s(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat4f_Mat1w(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat4f_Mat2w(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat4f_Mat3w(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat4f_Mat4w(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat4f_Mat1i(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat4f_Mat2i(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat4f_Mat3i(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat4f_Mat4i(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat4f_Mat1f(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat4f_Mat2f(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat4f_Mat3f(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<double> cvt_Mat4f_Mat1d(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat4f_Mat2d(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat4f_Mat3d(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat4f_Mat4d(::cv::Mat_<cv::Vec<float, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat1d_Mat1b(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat1d_Mat2b(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat1d_Mat3b(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat1d_Mat4b(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat1d_Mat1s(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat1d_Mat2s(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat1d_Mat3s(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat1d_Mat4s(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat1d_Mat1w(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat1d_Mat2w(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat1d_Mat3w(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat1d_Mat4w(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat1d_Mat1i(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat1d_Mat2i(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat1d_Mat3i(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat1d_Mat4i(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat1d_Mat1f(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat1d_Mat2f(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat1d_Mat3f(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat1d_Mat4f(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat1d_Mat2d(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat1d_Mat3d(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat1d_Mat4d(::cv::Mat_<double> const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat2d_Mat1b(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat2d_Mat2b(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat2d_Mat3b(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat2d_Mat4b(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat2d_Mat1s(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat2d_Mat2s(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat2d_Mat3s(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat2d_Mat4s(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat2d_Mat1w(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat2d_Mat2w(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat2d_Mat3w(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat2d_Mat4w(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat2d_Mat1i(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat2d_Mat2i(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat2d_Mat3i(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat2d_Mat4i(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat2d_Mat1f(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat2d_Mat2f(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat2d_Mat3f(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat2d_Mat4f(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat2d_Mat1d(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat2d_Mat3d(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat2d_Mat4d(::cv::Mat_<cv::Vec<double, 2> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat3d_Mat1b(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat3d_Mat2b(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat3d_Mat3b(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat3d_Mat4b(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat3d_Mat1s(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat3d_Mat2s(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat3d_Mat3s(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat3d_Mat4s(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat3d_Mat1w(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat3d_Mat2w(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat3d_Mat3w(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat3d_Mat4w(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat3d_Mat1i(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat3d_Mat2i(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat3d_Mat3i(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat3d_Mat4i(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat3d_Mat1f(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat3d_Mat2f(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat3d_Mat3f(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat3d_Mat4f(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat3d_Mat1d(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat3d_Mat2d(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 4> > cvt_Mat3d_Mat4d(::cv::Mat_<cv::Vec<double, 3> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 4> >();
}

static inline ::cv::Mat_<unsigned char> cvt_Mat4d_Mat1b(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned char>();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 2> > cvt_Mat4d_Mat2b(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 3> > cvt_Mat4d_Mat3b(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned char, 4> > cvt_Mat4d_Mat4b(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned char, 4> >();
}

static inline ::cv::Mat_<short> cvt_Mat4d_Mat1s(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<short>();
}

static inline ::cv::Mat_<cv::Vec<short, 2> > cvt_Mat4d_Mat2s(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<short, 3> > cvt_Mat4d_Mat3s(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<short, 4> > cvt_Mat4d_Mat4s(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<short, 4> >();
}

static inline ::cv::Mat_<unsigned short> cvt_Mat4d_Mat1w(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<unsigned short>();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 2> > cvt_Mat4d_Mat2w(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 2> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 3> > cvt_Mat4d_Mat3w(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 3> >();
}

static inline ::cv::Mat_<cv::Vec<unsigned short, 4> > cvt_Mat4d_Mat4w(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<unsigned short, 4> >();
}

static inline ::cv::Mat_<int> cvt_Mat4d_Mat1i(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<int>();
}

static inline ::cv::Mat_<cv::Vec<int, 2> > cvt_Mat4d_Mat2i(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 2> >();
}

static inline ::cv::Mat_<cv::Vec<int, 3> > cvt_Mat4d_Mat3i(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 3> >();
}

static inline ::cv::Mat_<cv::Vec<int, 4> > cvt_Mat4d_Mat4i(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<int, 4> >();
}

static inline ::cv::Mat_<float> cvt_Mat4d_Mat1f(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<float>();
}

static inline ::cv::Mat_<cv::Vec<float, 2> > cvt_Mat4d_Mat2f(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 2> >();
}

static inline ::cv::Mat_<cv::Vec<float, 3> > cvt_Mat4d_Mat3f(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 3> >();
}

static inline ::cv::Mat_<cv::Vec<float, 4> > cvt_Mat4d_Mat4f(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<float, 4> >();
}

static inline ::cv::Mat_<double> cvt_Mat4d_Mat1d(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<double>();
}

static inline ::cv::Mat_<cv::Vec<double, 2> > cvt_Mat4d_Mat2d(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 2> >();
}

static inline ::cv::Mat_<cv::Vec<double, 3> > cvt_Mat4d_Mat3d(::cv::Mat_<cv::Vec<double, 4> > const &inst)
{
    return inst.operator ::cv::Mat_<cv::Vec<double, 3> >();
}

void register___dummy_struct_class(){

    { //::cv::dummy_struct
        typedef bp::class_< cv::dummy_struct > __dummy_struct_exposer_t;
        __dummy_struct_exposer_t __dummy_struct_exposer = __dummy_struct_exposer_t( "__dummy_struct" );
        bp::scope __dummy_struct_scope( __dummy_struct_exposer );
        __dummy_struct_exposer.add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::dummy_struct >() );
        bp::class_< cv::dummy_struct::dummy_struct2 >( "dummy_struct2" )    
            .add_property( "this", pyplus_conv::make_addressof_inst_getter< cv::dummy_struct::dummy_struct2 >() );
        __dummy_struct_exposer.setattr("v0", 0);
    }
    {
        
        bp::def("asVec2s", &cvt_Vec2b_Vec2s, (bp::arg("inst_Vec2b")));
        bp::def("asVec2w", &cvt_Vec2b_Vec2w, (bp::arg("inst_Vec2b")));
        bp::def("asVec2i", &cvt_Vec2b_Vec2i, (bp::arg("inst_Vec2b")));
        bp::def("asVec2f", &cvt_Vec2b_Vec2f, (bp::arg("inst_Vec2b")));
        bp::def("asVec2d", &cvt_Vec2b_Vec2d, (bp::arg("inst_Vec2b")));
        bp::def("asVec2b", &cvt_Vec2s_Vec2b, (bp::arg("inst_Vec2s")));
        bp::def("asVec2w", &cvt_Vec2s_Vec2w, (bp::arg("inst_Vec2s")));
        bp::def("asVec2i", &cvt_Vec2s_Vec2i, (bp::arg("inst_Vec2s")));
        bp::def("asVec2f", &cvt_Vec2s_Vec2f, (bp::arg("inst_Vec2s")));
        bp::def("asVec2d", &cvt_Vec2s_Vec2d, (bp::arg("inst_Vec2s")));
        bp::def("asVec2b", &cvt_Vec2w_Vec2b, (bp::arg("inst_Vec2w")));
        bp::def("asVec2s", &cvt_Vec2w_Vec2s, (bp::arg("inst_Vec2w")));
        bp::def("asVec2i", &cvt_Vec2w_Vec2i, (bp::arg("inst_Vec2w")));
        bp::def("asVec2f", &cvt_Vec2w_Vec2f, (bp::arg("inst_Vec2w")));
        bp::def("asVec2d", &cvt_Vec2w_Vec2d, (bp::arg("inst_Vec2w")));
        bp::def("asVec2b", &cvt_Vec2i_Vec2b, (bp::arg("inst_Vec2i")));
        bp::def("asVec2s", &cvt_Vec2i_Vec2s, (bp::arg("inst_Vec2i")));
        bp::def("asVec2w", &cvt_Vec2i_Vec2w, (bp::arg("inst_Vec2i")));
        bp::def("asVec2f", &cvt_Vec2i_Vec2f, (bp::arg("inst_Vec2i")));
        bp::def("asVec2d", &cvt_Vec2i_Vec2d, (bp::arg("inst_Vec2i")));
        bp::def("asVec2b", &cvt_Vec2f_Vec2b, (bp::arg("inst_Vec2f")));
        bp::def("asVec2s", &cvt_Vec2f_Vec2s, (bp::arg("inst_Vec2f")));
        bp::def("asVec2w", &cvt_Vec2f_Vec2w, (bp::arg("inst_Vec2f")));
        bp::def("asVec2i", &cvt_Vec2f_Vec2i, (bp::arg("inst_Vec2f")));
        bp::def("asVec2d", &cvt_Vec2f_Vec2d, (bp::arg("inst_Vec2f")));
        bp::def("asVec2b", &cvt_Vec2d_Vec2b, (bp::arg("inst_Vec2d")));
        bp::def("asVec2s", &cvt_Vec2d_Vec2s, (bp::arg("inst_Vec2d")));
        bp::def("asVec2w", &cvt_Vec2d_Vec2w, (bp::arg("inst_Vec2d")));
        bp::def("asVec2i", &cvt_Vec2d_Vec2i, (bp::arg("inst_Vec2d")));
        bp::def("asVec2f", &cvt_Vec2d_Vec2f, (bp::arg("inst_Vec2d")));
        bp::def("asVec3s", &cvt_Vec3b_Vec3s, (bp::arg("inst_Vec3b")));
        bp::def("asVec3w", &cvt_Vec3b_Vec3w, (bp::arg("inst_Vec3b")));
        bp::def("asVec3i", &cvt_Vec3b_Vec3i, (bp::arg("inst_Vec3b")));
        bp::def("asVec3f", &cvt_Vec3b_Vec3f, (bp::arg("inst_Vec3b")));
        bp::def("asVec3d", &cvt_Vec3b_Vec3d, (bp::arg("inst_Vec3b")));
        bp::def("asVec3b", &cvt_Vec3s_Vec3b, (bp::arg("inst_Vec3s")));
        bp::def("asVec3w", &cvt_Vec3s_Vec3w, (bp::arg("inst_Vec3s")));
        bp::def("asVec3i", &cvt_Vec3s_Vec3i, (bp::arg("inst_Vec3s")));
        bp::def("asVec3f", &cvt_Vec3s_Vec3f, (bp::arg("inst_Vec3s")));
        bp::def("asVec3d", &cvt_Vec3s_Vec3d, (bp::arg("inst_Vec3s")));
        bp::def("asVec3b", &cvt_Vec3w_Vec3b, (bp::arg("inst_Vec3w")));
        bp::def("asVec3s", &cvt_Vec3w_Vec3s, (bp::arg("inst_Vec3w")));
        bp::def("asVec3i", &cvt_Vec3w_Vec3i, (bp::arg("inst_Vec3w")));
        bp::def("asVec3f", &cvt_Vec3w_Vec3f, (bp::arg("inst_Vec3w")));
        bp::def("asVec3d", &cvt_Vec3w_Vec3d, (bp::arg("inst_Vec3w")));
        bp::def("asVec3b", &cvt_Vec3i_Vec3b, (bp::arg("inst_Vec3i")));
        bp::def("asVec3s", &cvt_Vec3i_Vec3s, (bp::arg("inst_Vec3i")));
        bp::def("asVec3w", &cvt_Vec3i_Vec3w, (bp::arg("inst_Vec3i")));
        bp::def("asVec3f", &cvt_Vec3i_Vec3f, (bp::arg("inst_Vec3i")));
        bp::def("asVec3d", &cvt_Vec3i_Vec3d, (bp::arg("inst_Vec3i")));
        bp::def("asVec3b", &cvt_Vec3f_Vec3b, (bp::arg("inst_Vec3f")));
        bp::def("asVec3s", &cvt_Vec3f_Vec3s, (bp::arg("inst_Vec3f")));
        bp::def("asVec3w", &cvt_Vec3f_Vec3w, (bp::arg("inst_Vec3f")));
        bp::def("asVec3i", &cvt_Vec3f_Vec3i, (bp::arg("inst_Vec3f")));
        bp::def("asVec3d", &cvt_Vec3f_Vec3d, (bp::arg("inst_Vec3f")));
        bp::def("asVec3b", &cvt_Vec3d_Vec3b, (bp::arg("inst_Vec3d")));
        bp::def("asVec3s", &cvt_Vec3d_Vec3s, (bp::arg("inst_Vec3d")));
        bp::def("asVec3w", &cvt_Vec3d_Vec3w, (bp::arg("inst_Vec3d")));
        bp::def("asVec3i", &cvt_Vec3d_Vec3i, (bp::arg("inst_Vec3d")));
        bp::def("asVec3f", &cvt_Vec3d_Vec3f, (bp::arg("inst_Vec3d")));
        bp::def("asVec4s", &cvt_Vec4b_Vec4s, (bp::arg("inst_Vec4b")));
        bp::def("asVec4w", &cvt_Vec4b_Vec4w, (bp::arg("inst_Vec4b")));
        bp::def("asVec4i", &cvt_Vec4b_Vec4i, (bp::arg("inst_Vec4b")));
        bp::def("asVec4f", &cvt_Vec4b_Vec4f, (bp::arg("inst_Vec4b")));
        bp::def("asVec4d", &cvt_Vec4b_Vec4d, (bp::arg("inst_Vec4b")));
        bp::def("asVec4b", &cvt_Vec4s_Vec4b, (bp::arg("inst_Vec4s")));
        bp::def("asVec4w", &cvt_Vec4s_Vec4w, (bp::arg("inst_Vec4s")));
        bp::def("asVec4i", &cvt_Vec4s_Vec4i, (bp::arg("inst_Vec4s")));
        bp::def("asVec4f", &cvt_Vec4s_Vec4f, (bp::arg("inst_Vec4s")));
        bp::def("asVec4d", &cvt_Vec4s_Vec4d, (bp::arg("inst_Vec4s")));
        bp::def("asVec4b", &cvt_Vec4w_Vec4b, (bp::arg("inst_Vec4w")));
        bp::def("asVec4s", &cvt_Vec4w_Vec4s, (bp::arg("inst_Vec4w")));
        bp::def("asVec4i", &cvt_Vec4w_Vec4i, (bp::arg("inst_Vec4w")));
        bp::def("asVec4f", &cvt_Vec4w_Vec4f, (bp::arg("inst_Vec4w")));
        bp::def("asVec4d", &cvt_Vec4w_Vec4d, (bp::arg("inst_Vec4w")));
        bp::def("asVec4b", &cvt_Vec4i_Vec4b, (bp::arg("inst_Vec4i")));
        bp::def("asVec4s", &cvt_Vec4i_Vec4s, (bp::arg("inst_Vec4i")));
        bp::def("asVec4w", &cvt_Vec4i_Vec4w, (bp::arg("inst_Vec4i")));
        bp::def("asVec4f", &cvt_Vec4i_Vec4f, (bp::arg("inst_Vec4i")));
        bp::def("asVec4d", &cvt_Vec4i_Vec4d, (bp::arg("inst_Vec4i")));
        bp::def("asVec4b", &cvt_Vec4f_Vec4b, (bp::arg("inst_Vec4f")));
        bp::def("asVec4s", &cvt_Vec4f_Vec4s, (bp::arg("inst_Vec4f")));
        bp::def("asVec4w", &cvt_Vec4f_Vec4w, (bp::arg("inst_Vec4f")));
        bp::def("asVec4i", &cvt_Vec4f_Vec4i, (bp::arg("inst_Vec4f")));
        bp::def("asVec4d", &cvt_Vec4f_Vec4d, (bp::arg("inst_Vec4f")));
        bp::def("asVec4b", &cvt_Vec4d_Vec4b, (bp::arg("inst_Vec4d")));
        bp::def("asVec4s", &cvt_Vec4d_Vec4s, (bp::arg("inst_Vec4d")));
        bp::def("asVec4w", &cvt_Vec4d_Vec4w, (bp::arg("inst_Vec4d")));
        bp::def("asVec4i", &cvt_Vec4d_Vec4i, (bp::arg("inst_Vec4d")));
        bp::def("asVec4f", &cvt_Vec4d_Vec4f, (bp::arg("inst_Vec4d")));
        bp::def("asVec6d", &cvt_Vec6f_Vec6d, (bp::arg("inst_Vec6f")));
        bp::def("asVec6f", &cvt_Vec6d_Vec6f, (bp::arg("inst_Vec6d")));
        bp::def("asComplexd", &cvt_Complexf_Complexd, (bp::arg("inst_Complexf")));
        bp::def("asComplexf", &cvt_Complexd_Complexf, (bp::arg("inst_Complexd")));
        bp::def("asPoint2f", &cvt_Point2i_Point2f, (bp::arg("inst_Point2i")));
        bp::def("asPoint2d", &cvt_Point2i_Point2d, (bp::arg("inst_Point2i")));
        bp::def("asPoint2i", &cvt_Point2f_Point2i, (bp::arg("inst_Point2f")));
        bp::def("asPoint2d", &cvt_Point2f_Point2d, (bp::arg("inst_Point2f")));
        bp::def("asPoint2i", &cvt_Point2d_Point2i, (bp::arg("inst_Point2d")));
        bp::def("asPoint2f", &cvt_Point2d_Point2f, (bp::arg("inst_Point2d")));
        bp::def("asPoint3f", &cvt_Point3i_Point3f, (bp::arg("inst_Point3i")));
        bp::def("asPoint3d", &cvt_Point3i_Point3d, (bp::arg("inst_Point3i")));
        bp::def("asPoint3i", &cvt_Point3f_Point3i, (bp::arg("inst_Point3f")));
        bp::def("asPoint3d", &cvt_Point3f_Point3d, (bp::arg("inst_Point3f")));
        bp::def("asPoint3i", &cvt_Point3d_Point3i, (bp::arg("inst_Point3d")));
        bp::def("asPoint3f", &cvt_Point3d_Point3f, (bp::arg("inst_Point3d")));
        bp::def("asSize2f", &cvt_Size2i_Size2f, (bp::arg("inst_Size2i")));
        bp::def("asSize2d", &cvt_Size2i_Size2d, (bp::arg("inst_Size2i")));
        bp::def("asSize2i", &cvt_Size2f_Size2i, (bp::arg("inst_Size2f")));
        bp::def("asSize2d", &cvt_Size2f_Size2d, (bp::arg("inst_Size2f")));
        bp::def("asSize2i", &cvt_Size2d_Size2i, (bp::arg("inst_Size2d")));
        bp::def("asSize2f", &cvt_Size2d_Size2f, (bp::arg("inst_Size2d")));
        bp::def("asRectf", &cvt_Rect_Rectf, (bp::arg("inst_Rect")));
        bp::def("asRectd", &cvt_Rect_Rectd, (bp::arg("inst_Rect")));
        bp::def("asRect", &cvt_Rectf_Rect, (bp::arg("inst_Rectf")));
        bp::def("asRectd", &cvt_Rectf_Rectd, (bp::arg("inst_Rectf")));
        bp::def("asRect", &cvt_Rectd_Rect, (bp::arg("inst_Rectd")));
        bp::def("asRectf", &cvt_Rectd_Rectf, (bp::arg("inst_Rectd")));
        bp::def("asMat2b", &cvt_Mat1b_Mat2b, (bp::arg("inst_Mat1b")));
        bp::def("asMat3b", &cvt_Mat1b_Mat3b, (bp::arg("inst_Mat1b")));
        bp::def("asMat4b", &cvt_Mat1b_Mat4b, (bp::arg("inst_Mat1b")));
        bp::def("asMat1s", &cvt_Mat1b_Mat1s, (bp::arg("inst_Mat1b")));
        bp::def("asMat2s", &cvt_Mat1b_Mat2s, (bp::arg("inst_Mat1b")));
        bp::def("asMat3s", &cvt_Mat1b_Mat3s, (bp::arg("inst_Mat1b")));
        bp::def("asMat4s", &cvt_Mat1b_Mat4s, (bp::arg("inst_Mat1b")));
        bp::def("asMat1w", &cvt_Mat1b_Mat1w, (bp::arg("inst_Mat1b")));
        bp::def("asMat2w", &cvt_Mat1b_Mat2w, (bp::arg("inst_Mat1b")));
        bp::def("asMat3w", &cvt_Mat1b_Mat3w, (bp::arg("inst_Mat1b")));
        bp::def("asMat4w", &cvt_Mat1b_Mat4w, (bp::arg("inst_Mat1b")));
        bp::def("asMat1i", &cvt_Mat1b_Mat1i, (bp::arg("inst_Mat1b")));
        bp::def("asMat2i", &cvt_Mat1b_Mat2i, (bp::arg("inst_Mat1b")));
        bp::def("asMat3i", &cvt_Mat1b_Mat3i, (bp::arg("inst_Mat1b")));
        bp::def("asMat4i", &cvt_Mat1b_Mat4i, (bp::arg("inst_Mat1b")));
        bp::def("asMat1f", &cvt_Mat1b_Mat1f, (bp::arg("inst_Mat1b")));
        bp::def("asMat2f", &cvt_Mat1b_Mat2f, (bp::arg("inst_Mat1b")));
        bp::def("asMat3f", &cvt_Mat1b_Mat3f, (bp::arg("inst_Mat1b")));
        bp::def("asMat4f", &cvt_Mat1b_Mat4f, (bp::arg("inst_Mat1b")));
        bp::def("asMat1d", &cvt_Mat1b_Mat1d, (bp::arg("inst_Mat1b")));
        bp::def("asMat2d", &cvt_Mat1b_Mat2d, (bp::arg("inst_Mat1b")));
        bp::def("asMat3d", &cvt_Mat1b_Mat3d, (bp::arg("inst_Mat1b")));
        bp::def("asMat4d", &cvt_Mat1b_Mat4d, (bp::arg("inst_Mat1b")));
        bp::def("asMat1b", &cvt_Mat2b_Mat1b, (bp::arg("inst_Mat2b")));
        bp::def("asMat3b", &cvt_Mat2b_Mat3b, (bp::arg("inst_Mat2b")));
        bp::def("asMat4b", &cvt_Mat2b_Mat4b, (bp::arg("inst_Mat2b")));
        bp::def("asMat1s", &cvt_Mat2b_Mat1s, (bp::arg("inst_Mat2b")));
        bp::def("asMat2s", &cvt_Mat2b_Mat2s, (bp::arg("inst_Mat2b")));
        bp::def("asMat3s", &cvt_Mat2b_Mat3s, (bp::arg("inst_Mat2b")));
        bp::def("asMat4s", &cvt_Mat2b_Mat4s, (bp::arg("inst_Mat2b")));
        bp::def("asMat1w", &cvt_Mat2b_Mat1w, (bp::arg("inst_Mat2b")));
        bp::def("asMat2w", &cvt_Mat2b_Mat2w, (bp::arg("inst_Mat2b")));
        bp::def("asMat3w", &cvt_Mat2b_Mat3w, (bp::arg("inst_Mat2b")));
        bp::def("asMat4w", &cvt_Mat2b_Mat4w, (bp::arg("inst_Mat2b")));
        bp::def("asMat1i", &cvt_Mat2b_Mat1i, (bp::arg("inst_Mat2b")));
        bp::def("asMat2i", &cvt_Mat2b_Mat2i, (bp::arg("inst_Mat2b")));
        bp::def("asMat3i", &cvt_Mat2b_Mat3i, (bp::arg("inst_Mat2b")));
        bp::def("asMat4i", &cvt_Mat2b_Mat4i, (bp::arg("inst_Mat2b")));
        bp::def("asMat1f", &cvt_Mat2b_Mat1f, (bp::arg("inst_Mat2b")));
        bp::def("asMat2f", &cvt_Mat2b_Mat2f, (bp::arg("inst_Mat2b")));
        bp::def("asMat3f", &cvt_Mat2b_Mat3f, (bp::arg("inst_Mat2b")));
        bp::def("asMat4f", &cvt_Mat2b_Mat4f, (bp::arg("inst_Mat2b")));
        bp::def("asMat1d", &cvt_Mat2b_Mat1d, (bp::arg("inst_Mat2b")));
        bp::def("asMat2d", &cvt_Mat2b_Mat2d, (bp::arg("inst_Mat2b")));
        bp::def("asMat3d", &cvt_Mat2b_Mat3d, (bp::arg("inst_Mat2b")));
        bp::def("asMat4d", &cvt_Mat2b_Mat4d, (bp::arg("inst_Mat2b")));
        bp::def("asMat1b", &cvt_Mat3b_Mat1b, (bp::arg("inst_Mat3b")));
        bp::def("asMat2b", &cvt_Mat3b_Mat2b, (bp::arg("inst_Mat3b")));
        bp::def("asMat4b", &cvt_Mat3b_Mat4b, (bp::arg("inst_Mat3b")));
        bp::def("asMat1s", &cvt_Mat3b_Mat1s, (bp::arg("inst_Mat3b")));
        bp::def("asMat2s", &cvt_Mat3b_Mat2s, (bp::arg("inst_Mat3b")));
        bp::def("asMat3s", &cvt_Mat3b_Mat3s, (bp::arg("inst_Mat3b")));
        bp::def("asMat4s", &cvt_Mat3b_Mat4s, (bp::arg("inst_Mat3b")));
        bp::def("asMat1w", &cvt_Mat3b_Mat1w, (bp::arg("inst_Mat3b")));
        bp::def("asMat2w", &cvt_Mat3b_Mat2w, (bp::arg("inst_Mat3b")));
        bp::def("asMat3w", &cvt_Mat3b_Mat3w, (bp::arg("inst_Mat3b")));
        bp::def("asMat4w", &cvt_Mat3b_Mat4w, (bp::arg("inst_Mat3b")));
        bp::def("asMat1i", &cvt_Mat3b_Mat1i, (bp::arg("inst_Mat3b")));
        bp::def("asMat2i", &cvt_Mat3b_Mat2i, (bp::arg("inst_Mat3b")));
        bp::def("asMat3i", &cvt_Mat3b_Mat3i, (bp::arg("inst_Mat3b")));
        bp::def("asMat4i", &cvt_Mat3b_Mat4i, (bp::arg("inst_Mat3b")));
        bp::def("asMat1f", &cvt_Mat3b_Mat1f, (bp::arg("inst_Mat3b")));
        bp::def("asMat2f", &cvt_Mat3b_Mat2f, (bp::arg("inst_Mat3b")));
        bp::def("asMat3f", &cvt_Mat3b_Mat3f, (bp::arg("inst_Mat3b")));
        bp::def("asMat4f", &cvt_Mat3b_Mat4f, (bp::arg("inst_Mat3b")));
        bp::def("asMat1d", &cvt_Mat3b_Mat1d, (bp::arg("inst_Mat3b")));
        bp::def("asMat2d", &cvt_Mat3b_Mat2d, (bp::arg("inst_Mat3b")));
        bp::def("asMat3d", &cvt_Mat3b_Mat3d, (bp::arg("inst_Mat3b")));
        bp::def("asMat4d", &cvt_Mat3b_Mat4d, (bp::arg("inst_Mat3b")));
        bp::def("asMat1b", &cvt_Mat4b_Mat1b, (bp::arg("inst_Mat4b")));
        bp::def("asMat2b", &cvt_Mat4b_Mat2b, (bp::arg("inst_Mat4b")));
        bp::def("asMat3b", &cvt_Mat4b_Mat3b, (bp::arg("inst_Mat4b")));
        bp::def("asMat1s", &cvt_Mat4b_Mat1s, (bp::arg("inst_Mat4b")));
        bp::def("asMat2s", &cvt_Mat4b_Mat2s, (bp::arg("inst_Mat4b")));
        bp::def("asMat3s", &cvt_Mat4b_Mat3s, (bp::arg("inst_Mat4b")));
        bp::def("asMat4s", &cvt_Mat4b_Mat4s, (bp::arg("inst_Mat4b")));
        bp::def("asMat1w", &cvt_Mat4b_Mat1w, (bp::arg("inst_Mat4b")));
        bp::def("asMat2w", &cvt_Mat4b_Mat2w, (bp::arg("inst_Mat4b")));
        bp::def("asMat3w", &cvt_Mat4b_Mat3w, (bp::arg("inst_Mat4b")));
        bp::def("asMat4w", &cvt_Mat4b_Mat4w, (bp::arg("inst_Mat4b")));
        bp::def("asMat1i", &cvt_Mat4b_Mat1i, (bp::arg("inst_Mat4b")));
        bp::def("asMat2i", &cvt_Mat4b_Mat2i, (bp::arg("inst_Mat4b")));
        bp::def("asMat3i", &cvt_Mat4b_Mat3i, (bp::arg("inst_Mat4b")));
        bp::def("asMat4i", &cvt_Mat4b_Mat4i, (bp::arg("inst_Mat4b")));
        bp::def("asMat1f", &cvt_Mat4b_Mat1f, (bp::arg("inst_Mat4b")));
        bp::def("asMat2f", &cvt_Mat4b_Mat2f, (bp::arg("inst_Mat4b")));
        bp::def("asMat3f", &cvt_Mat4b_Mat3f, (bp::arg("inst_Mat4b")));
        bp::def("asMat4f", &cvt_Mat4b_Mat4f, (bp::arg("inst_Mat4b")));
        bp::def("asMat1d", &cvt_Mat4b_Mat1d, (bp::arg("inst_Mat4b")));
        bp::def("asMat2d", &cvt_Mat4b_Mat2d, (bp::arg("inst_Mat4b")));
        bp::def("asMat3d", &cvt_Mat4b_Mat3d, (bp::arg("inst_Mat4b")));
        bp::def("asMat4d", &cvt_Mat4b_Mat4d, (bp::arg("inst_Mat4b")));
        bp::def("asMat1b", &cvt_Mat1s_Mat1b, (bp::arg("inst_Mat1s")));
        bp::def("asMat2b", &cvt_Mat1s_Mat2b, (bp::arg("inst_Mat1s")));
        bp::def("asMat3b", &cvt_Mat1s_Mat3b, (bp::arg("inst_Mat1s")));
        bp::def("asMat4b", &cvt_Mat1s_Mat4b, (bp::arg("inst_Mat1s")));
        bp::def("asMat2s", &cvt_Mat1s_Mat2s, (bp::arg("inst_Mat1s")));
        bp::def("asMat3s", &cvt_Mat1s_Mat3s, (bp::arg("inst_Mat1s")));
        bp::def("asMat4s", &cvt_Mat1s_Mat4s, (bp::arg("inst_Mat1s")));
        bp::def("asMat1w", &cvt_Mat1s_Mat1w, (bp::arg("inst_Mat1s")));
        bp::def("asMat2w", &cvt_Mat1s_Mat2w, (bp::arg("inst_Mat1s")));
        bp::def("asMat3w", &cvt_Mat1s_Mat3w, (bp::arg("inst_Mat1s")));
        bp::def("asMat4w", &cvt_Mat1s_Mat4w, (bp::arg("inst_Mat1s")));
        bp::def("asMat1i", &cvt_Mat1s_Mat1i, (bp::arg("inst_Mat1s")));
        bp::def("asMat2i", &cvt_Mat1s_Mat2i, (bp::arg("inst_Mat1s")));
        bp::def("asMat3i", &cvt_Mat1s_Mat3i, (bp::arg("inst_Mat1s")));
        bp::def("asMat4i", &cvt_Mat1s_Mat4i, (bp::arg("inst_Mat1s")));
        bp::def("asMat1f", &cvt_Mat1s_Mat1f, (bp::arg("inst_Mat1s")));
        bp::def("asMat2f", &cvt_Mat1s_Mat2f, (bp::arg("inst_Mat1s")));
        bp::def("asMat3f", &cvt_Mat1s_Mat3f, (bp::arg("inst_Mat1s")));
        bp::def("asMat4f", &cvt_Mat1s_Mat4f, (bp::arg("inst_Mat1s")));
        bp::def("asMat1d", &cvt_Mat1s_Mat1d, (bp::arg("inst_Mat1s")));
        bp::def("asMat2d", &cvt_Mat1s_Mat2d, (bp::arg("inst_Mat1s")));
        bp::def("asMat3d", &cvt_Mat1s_Mat3d, (bp::arg("inst_Mat1s")));
        bp::def("asMat4d", &cvt_Mat1s_Mat4d, (bp::arg("inst_Mat1s")));
        bp::def("asMat1b", &cvt_Mat2s_Mat1b, (bp::arg("inst_Mat2s")));
        bp::def("asMat2b", &cvt_Mat2s_Mat2b, (bp::arg("inst_Mat2s")));
        bp::def("asMat3b", &cvt_Mat2s_Mat3b, (bp::arg("inst_Mat2s")));
        bp::def("asMat4b", &cvt_Mat2s_Mat4b, (bp::arg("inst_Mat2s")));
        bp::def("asMat1s", &cvt_Mat2s_Mat1s, (bp::arg("inst_Mat2s")));
        bp::def("asMat3s", &cvt_Mat2s_Mat3s, (bp::arg("inst_Mat2s")));
        bp::def("asMat4s", &cvt_Mat2s_Mat4s, (bp::arg("inst_Mat2s")));
        bp::def("asMat1w", &cvt_Mat2s_Mat1w, (bp::arg("inst_Mat2s")));
        bp::def("asMat2w", &cvt_Mat2s_Mat2w, (bp::arg("inst_Mat2s")));
        bp::def("asMat3w", &cvt_Mat2s_Mat3w, (bp::arg("inst_Mat2s")));
        bp::def("asMat4w", &cvt_Mat2s_Mat4w, (bp::arg("inst_Mat2s")));
        bp::def("asMat1i", &cvt_Mat2s_Mat1i, (bp::arg("inst_Mat2s")));
        bp::def("asMat2i", &cvt_Mat2s_Mat2i, (bp::arg("inst_Mat2s")));
        bp::def("asMat3i", &cvt_Mat2s_Mat3i, (bp::arg("inst_Mat2s")));
        bp::def("asMat4i", &cvt_Mat2s_Mat4i, (bp::arg("inst_Mat2s")));
        bp::def("asMat1f", &cvt_Mat2s_Mat1f, (bp::arg("inst_Mat2s")));
        bp::def("asMat2f", &cvt_Mat2s_Mat2f, (bp::arg("inst_Mat2s")));
        bp::def("asMat3f", &cvt_Mat2s_Mat3f, (bp::arg("inst_Mat2s")));
        bp::def("asMat4f", &cvt_Mat2s_Mat4f, (bp::arg("inst_Mat2s")));
        bp::def("asMat1d", &cvt_Mat2s_Mat1d, (bp::arg("inst_Mat2s")));
        bp::def("asMat2d", &cvt_Mat2s_Mat2d, (bp::arg("inst_Mat2s")));
        bp::def("asMat3d", &cvt_Mat2s_Mat3d, (bp::arg("inst_Mat2s")));
        bp::def("asMat4d", &cvt_Mat2s_Mat4d, (bp::arg("inst_Mat2s")));
        bp::def("asMat1b", &cvt_Mat3s_Mat1b, (bp::arg("inst_Mat3s")));
        bp::def("asMat2b", &cvt_Mat3s_Mat2b, (bp::arg("inst_Mat3s")));
        bp::def("asMat3b", &cvt_Mat3s_Mat3b, (bp::arg("inst_Mat3s")));
        bp::def("asMat4b", &cvt_Mat3s_Mat4b, (bp::arg("inst_Mat3s")));
        bp::def("asMat1s", &cvt_Mat3s_Mat1s, (bp::arg("inst_Mat3s")));
        bp::def("asMat2s", &cvt_Mat3s_Mat2s, (bp::arg("inst_Mat3s")));
        bp::def("asMat4s", &cvt_Mat3s_Mat4s, (bp::arg("inst_Mat3s")));
        bp::def("asMat1w", &cvt_Mat3s_Mat1w, (bp::arg("inst_Mat3s")));
        bp::def("asMat2w", &cvt_Mat3s_Mat2w, (bp::arg("inst_Mat3s")));
        bp::def("asMat3w", &cvt_Mat3s_Mat3w, (bp::arg("inst_Mat3s")));
        bp::def("asMat4w", &cvt_Mat3s_Mat4w, (bp::arg("inst_Mat3s")));
        bp::def("asMat1i", &cvt_Mat3s_Mat1i, (bp::arg("inst_Mat3s")));
        bp::def("asMat2i", &cvt_Mat3s_Mat2i, (bp::arg("inst_Mat3s")));
        bp::def("asMat3i", &cvt_Mat3s_Mat3i, (bp::arg("inst_Mat3s")));
        bp::def("asMat4i", &cvt_Mat3s_Mat4i, (bp::arg("inst_Mat3s")));
        bp::def("asMat1f", &cvt_Mat3s_Mat1f, (bp::arg("inst_Mat3s")));
        bp::def("asMat2f", &cvt_Mat3s_Mat2f, (bp::arg("inst_Mat3s")));
        bp::def("asMat3f", &cvt_Mat3s_Mat3f, (bp::arg("inst_Mat3s")));
        bp::def("asMat4f", &cvt_Mat3s_Mat4f, (bp::arg("inst_Mat3s")));
        bp::def("asMat1d", &cvt_Mat3s_Mat1d, (bp::arg("inst_Mat3s")));
        bp::def("asMat2d", &cvt_Mat3s_Mat2d, (bp::arg("inst_Mat3s")));
        bp::def("asMat3d", &cvt_Mat3s_Mat3d, (bp::arg("inst_Mat3s")));
        bp::def("asMat4d", &cvt_Mat3s_Mat4d, (bp::arg("inst_Mat3s")));
        bp::def("asMat1b", &cvt_Mat4s_Mat1b, (bp::arg("inst_Mat4s")));
        bp::def("asMat2b", &cvt_Mat4s_Mat2b, (bp::arg("inst_Mat4s")));
        bp::def("asMat3b", &cvt_Mat4s_Mat3b, (bp::arg("inst_Mat4s")));
        bp::def("asMat4b", &cvt_Mat4s_Mat4b, (bp::arg("inst_Mat4s")));
        bp::def("asMat1s", &cvt_Mat4s_Mat1s, (bp::arg("inst_Mat4s")));
        bp::def("asMat2s", &cvt_Mat4s_Mat2s, (bp::arg("inst_Mat4s")));
        bp::def("asMat3s", &cvt_Mat4s_Mat3s, (bp::arg("inst_Mat4s")));
        bp::def("asMat1w", &cvt_Mat4s_Mat1w, (bp::arg("inst_Mat4s")));
        bp::def("asMat2w", &cvt_Mat4s_Mat2w, (bp::arg("inst_Mat4s")));
        bp::def("asMat3w", &cvt_Mat4s_Mat3w, (bp::arg("inst_Mat4s")));
        bp::def("asMat4w", &cvt_Mat4s_Mat4w, (bp::arg("inst_Mat4s")));
        bp::def("asMat1i", &cvt_Mat4s_Mat1i, (bp::arg("inst_Mat4s")));
        bp::def("asMat2i", &cvt_Mat4s_Mat2i, (bp::arg("inst_Mat4s")));
        bp::def("asMat3i", &cvt_Mat4s_Mat3i, (bp::arg("inst_Mat4s")));
        bp::def("asMat4i", &cvt_Mat4s_Mat4i, (bp::arg("inst_Mat4s")));
        bp::def("asMat1f", &cvt_Mat4s_Mat1f, (bp::arg("inst_Mat4s")));
        bp::def("asMat2f", &cvt_Mat4s_Mat2f, (bp::arg("inst_Mat4s")));
        bp::def("asMat3f", &cvt_Mat4s_Mat3f, (bp::arg("inst_Mat4s")));
        bp::def("asMat4f", &cvt_Mat4s_Mat4f, (bp::arg("inst_Mat4s")));
        bp::def("asMat1d", &cvt_Mat4s_Mat1d, (bp::arg("inst_Mat4s")));
        bp::def("asMat2d", &cvt_Mat4s_Mat2d, (bp::arg("inst_Mat4s")));
        bp::def("asMat3d", &cvt_Mat4s_Mat3d, (bp::arg("inst_Mat4s")));
        bp::def("asMat4d", &cvt_Mat4s_Mat4d, (bp::arg("inst_Mat4s")));
        bp::def("asMat1b", &cvt_Mat1w_Mat1b, (bp::arg("inst_Mat1w")));
        bp::def("asMat2b", &cvt_Mat1w_Mat2b, (bp::arg("inst_Mat1w")));
        bp::def("asMat3b", &cvt_Mat1w_Mat3b, (bp::arg("inst_Mat1w")));
        bp::def("asMat4b", &cvt_Mat1w_Mat4b, (bp::arg("inst_Mat1w")));
        bp::def("asMat1s", &cvt_Mat1w_Mat1s, (bp::arg("inst_Mat1w")));
        bp::def("asMat2s", &cvt_Mat1w_Mat2s, (bp::arg("inst_Mat1w")));
        bp::def("asMat3s", &cvt_Mat1w_Mat3s, (bp::arg("inst_Mat1w")));
        bp::def("asMat4s", &cvt_Mat1w_Mat4s, (bp::arg("inst_Mat1w")));
        bp::def("asMat2w", &cvt_Mat1w_Mat2w, (bp::arg("inst_Mat1w")));
        bp::def("asMat3w", &cvt_Mat1w_Mat3w, (bp::arg("inst_Mat1w")));
        bp::def("asMat4w", &cvt_Mat1w_Mat4w, (bp::arg("inst_Mat1w")));
        bp::def("asMat1i", &cvt_Mat1w_Mat1i, (bp::arg("inst_Mat1w")));
        bp::def("asMat2i", &cvt_Mat1w_Mat2i, (bp::arg("inst_Mat1w")));
        bp::def("asMat3i", &cvt_Mat1w_Mat3i, (bp::arg("inst_Mat1w")));
        bp::def("asMat4i", &cvt_Mat1w_Mat4i, (bp::arg("inst_Mat1w")));
        bp::def("asMat1f", &cvt_Mat1w_Mat1f, (bp::arg("inst_Mat1w")));
        bp::def("asMat2f", &cvt_Mat1w_Mat2f, (bp::arg("inst_Mat1w")));
        bp::def("asMat3f", &cvt_Mat1w_Mat3f, (bp::arg("inst_Mat1w")));
        bp::def("asMat4f", &cvt_Mat1w_Mat4f, (bp::arg("inst_Mat1w")));
        bp::def("asMat1d", &cvt_Mat1w_Mat1d, (bp::arg("inst_Mat1w")));
        bp::def("asMat2d", &cvt_Mat1w_Mat2d, (bp::arg("inst_Mat1w")));
        bp::def("asMat3d", &cvt_Mat1w_Mat3d, (bp::arg("inst_Mat1w")));
        bp::def("asMat4d", &cvt_Mat1w_Mat4d, (bp::arg("inst_Mat1w")));
        bp::def("asMat1b", &cvt_Mat2w_Mat1b, (bp::arg("inst_Mat2w")));
        bp::def("asMat2b", &cvt_Mat2w_Mat2b, (bp::arg("inst_Mat2w")));
        bp::def("asMat3b", &cvt_Mat2w_Mat3b, (bp::arg("inst_Mat2w")));
        bp::def("asMat4b", &cvt_Mat2w_Mat4b, (bp::arg("inst_Mat2w")));
        bp::def("asMat1s", &cvt_Mat2w_Mat1s, (bp::arg("inst_Mat2w")));
        bp::def("asMat2s", &cvt_Mat2w_Mat2s, (bp::arg("inst_Mat2w")));
        bp::def("asMat3s", &cvt_Mat2w_Mat3s, (bp::arg("inst_Mat2w")));
        bp::def("asMat4s", &cvt_Mat2w_Mat4s, (bp::arg("inst_Mat2w")));
        bp::def("asMat1w", &cvt_Mat2w_Mat1w, (bp::arg("inst_Mat2w")));
        bp::def("asMat3w", &cvt_Mat2w_Mat3w, (bp::arg("inst_Mat2w")));
        bp::def("asMat4w", &cvt_Mat2w_Mat4w, (bp::arg("inst_Mat2w")));
        bp::def("asMat1i", &cvt_Mat2w_Mat1i, (bp::arg("inst_Mat2w")));
        bp::def("asMat2i", &cvt_Mat2w_Mat2i, (bp::arg("inst_Mat2w")));
        bp::def("asMat3i", &cvt_Mat2w_Mat3i, (bp::arg("inst_Mat2w")));
        bp::def("asMat4i", &cvt_Mat2w_Mat4i, (bp::arg("inst_Mat2w")));
        bp::def("asMat1f", &cvt_Mat2w_Mat1f, (bp::arg("inst_Mat2w")));
        bp::def("asMat2f", &cvt_Mat2w_Mat2f, (bp::arg("inst_Mat2w")));
        bp::def("asMat3f", &cvt_Mat2w_Mat3f, (bp::arg("inst_Mat2w")));
        bp::def("asMat4f", &cvt_Mat2w_Mat4f, (bp::arg("inst_Mat2w")));
        bp::def("asMat1d", &cvt_Mat2w_Mat1d, (bp::arg("inst_Mat2w")));
        bp::def("asMat2d", &cvt_Mat2w_Mat2d, (bp::arg("inst_Mat2w")));
        bp::def("asMat3d", &cvt_Mat2w_Mat3d, (bp::arg("inst_Mat2w")));
        bp::def("asMat4d", &cvt_Mat2w_Mat4d, (bp::arg("inst_Mat2w")));
        bp::def("asMat1b", &cvt_Mat3w_Mat1b, (bp::arg("inst_Mat3w")));
        bp::def("asMat2b", &cvt_Mat3w_Mat2b, (bp::arg("inst_Mat3w")));
        bp::def("asMat3b", &cvt_Mat3w_Mat3b, (bp::arg("inst_Mat3w")));
        bp::def("asMat4b", &cvt_Mat3w_Mat4b, (bp::arg("inst_Mat3w")));
        bp::def("asMat1s", &cvt_Mat3w_Mat1s, (bp::arg("inst_Mat3w")));
        bp::def("asMat2s", &cvt_Mat3w_Mat2s, (bp::arg("inst_Mat3w")));
        bp::def("asMat3s", &cvt_Mat3w_Mat3s, (bp::arg("inst_Mat3w")));
        bp::def("asMat4s", &cvt_Mat3w_Mat4s, (bp::arg("inst_Mat3w")));
        bp::def("asMat1w", &cvt_Mat3w_Mat1w, (bp::arg("inst_Mat3w")));
        bp::def("asMat2w", &cvt_Mat3w_Mat2w, (bp::arg("inst_Mat3w")));
        bp::def("asMat4w", &cvt_Mat3w_Mat4w, (bp::arg("inst_Mat3w")));
        bp::def("asMat1i", &cvt_Mat3w_Mat1i, (bp::arg("inst_Mat3w")));
        bp::def("asMat2i", &cvt_Mat3w_Mat2i, (bp::arg("inst_Mat3w")));
        bp::def("asMat3i", &cvt_Mat3w_Mat3i, (bp::arg("inst_Mat3w")));
        bp::def("asMat4i", &cvt_Mat3w_Mat4i, (bp::arg("inst_Mat3w")));
        bp::def("asMat1f", &cvt_Mat3w_Mat1f, (bp::arg("inst_Mat3w")));
        bp::def("asMat2f", &cvt_Mat3w_Mat2f, (bp::arg("inst_Mat3w")));
        bp::def("asMat3f", &cvt_Mat3w_Mat3f, (bp::arg("inst_Mat3w")));
        bp::def("asMat4f", &cvt_Mat3w_Mat4f, (bp::arg("inst_Mat3w")));
        bp::def("asMat1d", &cvt_Mat3w_Mat1d, (bp::arg("inst_Mat3w")));
        bp::def("asMat2d", &cvt_Mat3w_Mat2d, (bp::arg("inst_Mat3w")));
        bp::def("asMat3d", &cvt_Mat3w_Mat3d, (bp::arg("inst_Mat3w")));
        bp::def("asMat4d", &cvt_Mat3w_Mat4d, (bp::arg("inst_Mat3w")));
        bp::def("asMat1b", &cvt_Mat4w_Mat1b, (bp::arg("inst_Mat4w")));
        bp::def("asMat2b", &cvt_Mat4w_Mat2b, (bp::arg("inst_Mat4w")));
        bp::def("asMat3b", &cvt_Mat4w_Mat3b, (bp::arg("inst_Mat4w")));
        bp::def("asMat4b", &cvt_Mat4w_Mat4b, (bp::arg("inst_Mat4w")));
        bp::def("asMat1s", &cvt_Mat4w_Mat1s, (bp::arg("inst_Mat4w")));
        bp::def("asMat2s", &cvt_Mat4w_Mat2s, (bp::arg("inst_Mat4w")));
        bp::def("asMat3s", &cvt_Mat4w_Mat3s, (bp::arg("inst_Mat4w")));
        bp::def("asMat4s", &cvt_Mat4w_Mat4s, (bp::arg("inst_Mat4w")));
        bp::def("asMat1w", &cvt_Mat4w_Mat1w, (bp::arg("inst_Mat4w")));
        bp::def("asMat2w", &cvt_Mat4w_Mat2w, (bp::arg("inst_Mat4w")));
        bp::def("asMat3w", &cvt_Mat4w_Mat3w, (bp::arg("inst_Mat4w")));
        bp::def("asMat1i", &cvt_Mat4w_Mat1i, (bp::arg("inst_Mat4w")));
        bp::def("asMat2i", &cvt_Mat4w_Mat2i, (bp::arg("inst_Mat4w")));
        bp::def("asMat3i", &cvt_Mat4w_Mat3i, (bp::arg("inst_Mat4w")));
        bp::def("asMat4i", &cvt_Mat4w_Mat4i, (bp::arg("inst_Mat4w")));
        bp::def("asMat1f", &cvt_Mat4w_Mat1f, (bp::arg("inst_Mat4w")));
        bp::def("asMat2f", &cvt_Mat4w_Mat2f, (bp::arg("inst_Mat4w")));
        bp::def("asMat3f", &cvt_Mat4w_Mat3f, (bp::arg("inst_Mat4w")));
        bp::def("asMat4f", &cvt_Mat4w_Mat4f, (bp::arg("inst_Mat4w")));
        bp::def("asMat1d", &cvt_Mat4w_Mat1d, (bp::arg("inst_Mat4w")));
        bp::def("asMat2d", &cvt_Mat4w_Mat2d, (bp::arg("inst_Mat4w")));
        bp::def("asMat3d", &cvt_Mat4w_Mat3d, (bp::arg("inst_Mat4w")));
        bp::def("asMat4d", &cvt_Mat4w_Mat4d, (bp::arg("inst_Mat4w")));
        bp::def("asMat1b", &cvt_Mat1i_Mat1b, (bp::arg("inst_Mat1i")));
        bp::def("asMat2b", &cvt_Mat1i_Mat2b, (bp::arg("inst_Mat1i")));
        bp::def("asMat3b", &cvt_Mat1i_Mat3b, (bp::arg("inst_Mat1i")));
        bp::def("asMat4b", &cvt_Mat1i_Mat4b, (bp::arg("inst_Mat1i")));
        bp::def("asMat1s", &cvt_Mat1i_Mat1s, (bp::arg("inst_Mat1i")));
        bp::def("asMat2s", &cvt_Mat1i_Mat2s, (bp::arg("inst_Mat1i")));
        bp::def("asMat3s", &cvt_Mat1i_Mat3s, (bp::arg("inst_Mat1i")));
        bp::def("asMat4s", &cvt_Mat1i_Mat4s, (bp::arg("inst_Mat1i")));
        bp::def("asMat1w", &cvt_Mat1i_Mat1w, (bp::arg("inst_Mat1i")));
        bp::def("asMat2w", &cvt_Mat1i_Mat2w, (bp::arg("inst_Mat1i")));
        bp::def("asMat3w", &cvt_Mat1i_Mat3w, (bp::arg("inst_Mat1i")));
        bp::def("asMat4w", &cvt_Mat1i_Mat4w, (bp::arg("inst_Mat1i")));
        bp::def("asMat2i", &cvt_Mat1i_Mat2i, (bp::arg("inst_Mat1i")));
        bp::def("asMat3i", &cvt_Mat1i_Mat3i, (bp::arg("inst_Mat1i")));
        bp::def("asMat4i", &cvt_Mat1i_Mat4i, (bp::arg("inst_Mat1i")));
        bp::def("asMat1f", &cvt_Mat1i_Mat1f, (bp::arg("inst_Mat1i")));
        bp::def("asMat2f", &cvt_Mat1i_Mat2f, (bp::arg("inst_Mat1i")));
        bp::def("asMat3f", &cvt_Mat1i_Mat3f, (bp::arg("inst_Mat1i")));
        bp::def("asMat4f", &cvt_Mat1i_Mat4f, (bp::arg("inst_Mat1i")));
        bp::def("asMat1d", &cvt_Mat1i_Mat1d, (bp::arg("inst_Mat1i")));
        bp::def("asMat2d", &cvt_Mat1i_Mat2d, (bp::arg("inst_Mat1i")));
        bp::def("asMat3d", &cvt_Mat1i_Mat3d, (bp::arg("inst_Mat1i")));
        bp::def("asMat4d", &cvt_Mat1i_Mat4d, (bp::arg("inst_Mat1i")));
        bp::def("asMat1b", &cvt_Mat2i_Mat1b, (bp::arg("inst_Mat2i")));
        bp::def("asMat2b", &cvt_Mat2i_Mat2b, (bp::arg("inst_Mat2i")));
        bp::def("asMat3b", &cvt_Mat2i_Mat3b, (bp::arg("inst_Mat2i")));
        bp::def("asMat4b", &cvt_Mat2i_Mat4b, (bp::arg("inst_Mat2i")));
        bp::def("asMat1s", &cvt_Mat2i_Mat1s, (bp::arg("inst_Mat2i")));
        bp::def("asMat2s", &cvt_Mat2i_Mat2s, (bp::arg("inst_Mat2i")));
        bp::def("asMat3s", &cvt_Mat2i_Mat3s, (bp::arg("inst_Mat2i")));
        bp::def("asMat4s", &cvt_Mat2i_Mat4s, (bp::arg("inst_Mat2i")));
        bp::def("asMat1w", &cvt_Mat2i_Mat1w, (bp::arg("inst_Mat2i")));
        bp::def("asMat2w", &cvt_Mat2i_Mat2w, (bp::arg("inst_Mat2i")));
        bp::def("asMat3w", &cvt_Mat2i_Mat3w, (bp::arg("inst_Mat2i")));
        bp::def("asMat4w", &cvt_Mat2i_Mat4w, (bp::arg("inst_Mat2i")));
        bp::def("asMat1i", &cvt_Mat2i_Mat1i, (bp::arg("inst_Mat2i")));
        bp::def("asMat3i", &cvt_Mat2i_Mat3i, (bp::arg("inst_Mat2i")));
        bp::def("asMat4i", &cvt_Mat2i_Mat4i, (bp::arg("inst_Mat2i")));
        bp::def("asMat1f", &cvt_Mat2i_Mat1f, (bp::arg("inst_Mat2i")));
        bp::def("asMat2f", &cvt_Mat2i_Mat2f, (bp::arg("inst_Mat2i")));
        bp::def("asMat3f", &cvt_Mat2i_Mat3f, (bp::arg("inst_Mat2i")));
        bp::def("asMat4f", &cvt_Mat2i_Mat4f, (bp::arg("inst_Mat2i")));
        bp::def("asMat1d", &cvt_Mat2i_Mat1d, (bp::arg("inst_Mat2i")));
        bp::def("asMat2d", &cvt_Mat2i_Mat2d, (bp::arg("inst_Mat2i")));
        bp::def("asMat3d", &cvt_Mat2i_Mat3d, (bp::arg("inst_Mat2i")));
        bp::def("asMat4d", &cvt_Mat2i_Mat4d, (bp::arg("inst_Mat2i")));
        bp::def("asMat1b", &cvt_Mat3i_Mat1b, (bp::arg("inst_Mat3i")));
        bp::def("asMat2b", &cvt_Mat3i_Mat2b, (bp::arg("inst_Mat3i")));
        bp::def("asMat3b", &cvt_Mat3i_Mat3b, (bp::arg("inst_Mat3i")));
        bp::def("asMat4b", &cvt_Mat3i_Mat4b, (bp::arg("inst_Mat3i")));
        bp::def("asMat1s", &cvt_Mat3i_Mat1s, (bp::arg("inst_Mat3i")));
        bp::def("asMat2s", &cvt_Mat3i_Mat2s, (bp::arg("inst_Mat3i")));
        bp::def("asMat3s", &cvt_Mat3i_Mat3s, (bp::arg("inst_Mat3i")));
        bp::def("asMat4s", &cvt_Mat3i_Mat4s, (bp::arg("inst_Mat3i")));
        bp::def("asMat1w", &cvt_Mat3i_Mat1w, (bp::arg("inst_Mat3i")));
        bp::def("asMat2w", &cvt_Mat3i_Mat2w, (bp::arg("inst_Mat3i")));
        bp::def("asMat3w", &cvt_Mat3i_Mat3w, (bp::arg("inst_Mat3i")));
        bp::def("asMat4w", &cvt_Mat3i_Mat4w, (bp::arg("inst_Mat3i")));
        bp::def("asMat1i", &cvt_Mat3i_Mat1i, (bp::arg("inst_Mat3i")));
        bp::def("asMat2i", &cvt_Mat3i_Mat2i, (bp::arg("inst_Mat3i")));
        bp::def("asMat4i", &cvt_Mat3i_Mat4i, (bp::arg("inst_Mat3i")));
        bp::def("asMat1f", &cvt_Mat3i_Mat1f, (bp::arg("inst_Mat3i")));
        bp::def("asMat2f", &cvt_Mat3i_Mat2f, (bp::arg("inst_Mat3i")));
        bp::def("asMat3f", &cvt_Mat3i_Mat3f, (bp::arg("inst_Mat3i")));
        bp::def("asMat4f", &cvt_Mat3i_Mat4f, (bp::arg("inst_Mat3i")));
        bp::def("asMat1d", &cvt_Mat3i_Mat1d, (bp::arg("inst_Mat3i")));
        bp::def("asMat2d", &cvt_Mat3i_Mat2d, (bp::arg("inst_Mat3i")));
        bp::def("asMat3d", &cvt_Mat3i_Mat3d, (bp::arg("inst_Mat3i")));
        bp::def("asMat4d", &cvt_Mat3i_Mat4d, (bp::arg("inst_Mat3i")));
        bp::def("asMat1b", &cvt_Mat4i_Mat1b, (bp::arg("inst_Mat4i")));
        bp::def("asMat2b", &cvt_Mat4i_Mat2b, (bp::arg("inst_Mat4i")));
        bp::def("asMat3b", &cvt_Mat4i_Mat3b, (bp::arg("inst_Mat4i")));
        bp::def("asMat4b", &cvt_Mat4i_Mat4b, (bp::arg("inst_Mat4i")));
        bp::def("asMat1s", &cvt_Mat4i_Mat1s, (bp::arg("inst_Mat4i")));
        bp::def("asMat2s", &cvt_Mat4i_Mat2s, (bp::arg("inst_Mat4i")));
        bp::def("asMat3s", &cvt_Mat4i_Mat3s, (bp::arg("inst_Mat4i")));
        bp::def("asMat4s", &cvt_Mat4i_Mat4s, (bp::arg("inst_Mat4i")));
        bp::def("asMat1w", &cvt_Mat4i_Mat1w, (bp::arg("inst_Mat4i")));
        bp::def("asMat2w", &cvt_Mat4i_Mat2w, (bp::arg("inst_Mat4i")));
        bp::def("asMat3w", &cvt_Mat4i_Mat3w, (bp::arg("inst_Mat4i")));
        bp::def("asMat4w", &cvt_Mat4i_Mat4w, (bp::arg("inst_Mat4i")));
        bp::def("asMat1i", &cvt_Mat4i_Mat1i, (bp::arg("inst_Mat4i")));
        bp::def("asMat2i", &cvt_Mat4i_Mat2i, (bp::arg("inst_Mat4i")));
        bp::def("asMat3i", &cvt_Mat4i_Mat3i, (bp::arg("inst_Mat4i")));
        bp::def("asMat1f", &cvt_Mat4i_Mat1f, (bp::arg("inst_Mat4i")));
        bp::def("asMat2f", &cvt_Mat4i_Mat2f, (bp::arg("inst_Mat4i")));
        bp::def("asMat3f", &cvt_Mat4i_Mat3f, (bp::arg("inst_Mat4i")));
        bp::def("asMat4f", &cvt_Mat4i_Mat4f, (bp::arg("inst_Mat4i")));
        bp::def("asMat1d", &cvt_Mat4i_Mat1d, (bp::arg("inst_Mat4i")));
        bp::def("asMat2d", &cvt_Mat4i_Mat2d, (bp::arg("inst_Mat4i")));
        bp::def("asMat3d", &cvt_Mat4i_Mat3d, (bp::arg("inst_Mat4i")));
        bp::def("asMat4d", &cvt_Mat4i_Mat4d, (bp::arg("inst_Mat4i")));
        bp::def("asMat1b", &cvt_Mat1f_Mat1b, (bp::arg("inst_Mat1f")));
        bp::def("asMat2b", &cvt_Mat1f_Mat2b, (bp::arg("inst_Mat1f")));
        bp::def("asMat3b", &cvt_Mat1f_Mat3b, (bp::arg("inst_Mat1f")));
        bp::def("asMat4b", &cvt_Mat1f_Mat4b, (bp::arg("inst_Mat1f")));
        bp::def("asMat1s", &cvt_Mat1f_Mat1s, (bp::arg("inst_Mat1f")));
        bp::def("asMat2s", &cvt_Mat1f_Mat2s, (bp::arg("inst_Mat1f")));
        bp::def("asMat3s", &cvt_Mat1f_Mat3s, (bp::arg("inst_Mat1f")));
        bp::def("asMat4s", &cvt_Mat1f_Mat4s, (bp::arg("inst_Mat1f")));
        bp::def("asMat1w", &cvt_Mat1f_Mat1w, (bp::arg("inst_Mat1f")));
        bp::def("asMat2w", &cvt_Mat1f_Mat2w, (bp::arg("inst_Mat1f")));
        bp::def("asMat3w", &cvt_Mat1f_Mat3w, (bp::arg("inst_Mat1f")));
        bp::def("asMat4w", &cvt_Mat1f_Mat4w, (bp::arg("inst_Mat1f")));
        bp::def("asMat1i", &cvt_Mat1f_Mat1i, (bp::arg("inst_Mat1f")));
        bp::def("asMat2i", &cvt_Mat1f_Mat2i, (bp::arg("inst_Mat1f")));
        bp::def("asMat3i", &cvt_Mat1f_Mat3i, (bp::arg("inst_Mat1f")));
        bp::def("asMat4i", &cvt_Mat1f_Mat4i, (bp::arg("inst_Mat1f")));
        bp::def("asMat2f", &cvt_Mat1f_Mat2f, (bp::arg("inst_Mat1f")));
        bp::def("asMat3f", &cvt_Mat1f_Mat3f, (bp::arg("inst_Mat1f")));
        bp::def("asMat4f", &cvt_Mat1f_Mat4f, (bp::arg("inst_Mat1f")));
        bp::def("asMat1d", &cvt_Mat1f_Mat1d, (bp::arg("inst_Mat1f")));
        bp::def("asMat2d", &cvt_Mat1f_Mat2d, (bp::arg("inst_Mat1f")));
        bp::def("asMat3d", &cvt_Mat1f_Mat3d, (bp::arg("inst_Mat1f")));
        bp::def("asMat4d", &cvt_Mat1f_Mat4d, (bp::arg("inst_Mat1f")));
        bp::def("asMat1b", &cvt_Mat2f_Mat1b, (bp::arg("inst_Mat2f")));
        bp::def("asMat2b", &cvt_Mat2f_Mat2b, (bp::arg("inst_Mat2f")));
        bp::def("asMat3b", &cvt_Mat2f_Mat3b, (bp::arg("inst_Mat2f")));
        bp::def("asMat4b", &cvt_Mat2f_Mat4b, (bp::arg("inst_Mat2f")));
        bp::def("asMat1s", &cvt_Mat2f_Mat1s, (bp::arg("inst_Mat2f")));
        bp::def("asMat2s", &cvt_Mat2f_Mat2s, (bp::arg("inst_Mat2f")));
        bp::def("asMat3s", &cvt_Mat2f_Mat3s, (bp::arg("inst_Mat2f")));
        bp::def("asMat4s", &cvt_Mat2f_Mat4s, (bp::arg("inst_Mat2f")));
        bp::def("asMat1w", &cvt_Mat2f_Mat1w, (bp::arg("inst_Mat2f")));
        bp::def("asMat2w", &cvt_Mat2f_Mat2w, (bp::arg("inst_Mat2f")));
        bp::def("asMat3w", &cvt_Mat2f_Mat3w, (bp::arg("inst_Mat2f")));
        bp::def("asMat4w", &cvt_Mat2f_Mat4w, (bp::arg("inst_Mat2f")));
        bp::def("asMat1i", &cvt_Mat2f_Mat1i, (bp::arg("inst_Mat2f")));
        bp::def("asMat2i", &cvt_Mat2f_Mat2i, (bp::arg("inst_Mat2f")));
        bp::def("asMat3i", &cvt_Mat2f_Mat3i, (bp::arg("inst_Mat2f")));
        bp::def("asMat4i", &cvt_Mat2f_Mat4i, (bp::arg("inst_Mat2f")));
        bp::def("asMat1f", &cvt_Mat2f_Mat1f, (bp::arg("inst_Mat2f")));
        bp::def("asMat3f", &cvt_Mat2f_Mat3f, (bp::arg("inst_Mat2f")));
        bp::def("asMat4f", &cvt_Mat2f_Mat4f, (bp::arg("inst_Mat2f")));
        bp::def("asMat1d", &cvt_Mat2f_Mat1d, (bp::arg("inst_Mat2f")));
        bp::def("asMat2d", &cvt_Mat2f_Mat2d, (bp::arg("inst_Mat2f")));
        bp::def("asMat3d", &cvt_Mat2f_Mat3d, (bp::arg("inst_Mat2f")));
        bp::def("asMat4d", &cvt_Mat2f_Mat4d, (bp::arg("inst_Mat2f")));
        bp::def("asMat1b", &cvt_Mat3f_Mat1b, (bp::arg("inst_Mat3f")));
        bp::def("asMat2b", &cvt_Mat3f_Mat2b, (bp::arg("inst_Mat3f")));
        bp::def("asMat3b", &cvt_Mat3f_Mat3b, (bp::arg("inst_Mat3f")));
        bp::def("asMat4b", &cvt_Mat3f_Mat4b, (bp::arg("inst_Mat3f")));
        bp::def("asMat1s", &cvt_Mat3f_Mat1s, (bp::arg("inst_Mat3f")));
        bp::def("asMat2s", &cvt_Mat3f_Mat2s, (bp::arg("inst_Mat3f")));
        bp::def("asMat3s", &cvt_Mat3f_Mat3s, (bp::arg("inst_Mat3f")));
        bp::def("asMat4s", &cvt_Mat3f_Mat4s, (bp::arg("inst_Mat3f")));
        bp::def("asMat1w", &cvt_Mat3f_Mat1w, (bp::arg("inst_Mat3f")));
        bp::def("asMat2w", &cvt_Mat3f_Mat2w, (bp::arg("inst_Mat3f")));
        bp::def("asMat3w", &cvt_Mat3f_Mat3w, (bp::arg("inst_Mat3f")));
        bp::def("asMat4w", &cvt_Mat3f_Mat4w, (bp::arg("inst_Mat3f")));
        bp::def("asMat1i", &cvt_Mat3f_Mat1i, (bp::arg("inst_Mat3f")));
        bp::def("asMat2i", &cvt_Mat3f_Mat2i, (bp::arg("inst_Mat3f")));
        bp::def("asMat3i", &cvt_Mat3f_Mat3i, (bp::arg("inst_Mat3f")));
        bp::def("asMat4i", &cvt_Mat3f_Mat4i, (bp::arg("inst_Mat3f")));
        bp::def("asMat1f", &cvt_Mat3f_Mat1f, (bp::arg("inst_Mat3f")));
        bp::def("asMat2f", &cvt_Mat3f_Mat2f, (bp::arg("inst_Mat3f")));
        bp::def("asMat4f", &cvt_Mat3f_Mat4f, (bp::arg("inst_Mat3f")));
        bp::def("asMat1d", &cvt_Mat3f_Mat1d, (bp::arg("inst_Mat3f")));
        bp::def("asMat2d", &cvt_Mat3f_Mat2d, (bp::arg("inst_Mat3f")));
        bp::def("asMat3d", &cvt_Mat3f_Mat3d, (bp::arg("inst_Mat3f")));
        bp::def("asMat4d", &cvt_Mat3f_Mat4d, (bp::arg("inst_Mat3f")));
        bp::def("asMat1b", &cvt_Mat4f_Mat1b, (bp::arg("inst_Mat4f")));
        bp::def("asMat2b", &cvt_Mat4f_Mat2b, (bp::arg("inst_Mat4f")));
        bp::def("asMat3b", &cvt_Mat4f_Mat3b, (bp::arg("inst_Mat4f")));
        bp::def("asMat4b", &cvt_Mat4f_Mat4b, (bp::arg("inst_Mat4f")));
        bp::def("asMat1s", &cvt_Mat4f_Mat1s, (bp::arg("inst_Mat4f")));
        bp::def("asMat2s", &cvt_Mat4f_Mat2s, (bp::arg("inst_Mat4f")));
        bp::def("asMat3s", &cvt_Mat4f_Mat3s, (bp::arg("inst_Mat4f")));
        bp::def("asMat4s", &cvt_Mat4f_Mat4s, (bp::arg("inst_Mat4f")));
        bp::def("asMat1w", &cvt_Mat4f_Mat1w, (bp::arg("inst_Mat4f")));
        bp::def("asMat2w", &cvt_Mat4f_Mat2w, (bp::arg("inst_Mat4f")));
        bp::def("asMat3w", &cvt_Mat4f_Mat3w, (bp::arg("inst_Mat4f")));
        bp::def("asMat4w", &cvt_Mat4f_Mat4w, (bp::arg("inst_Mat4f")));
        bp::def("asMat1i", &cvt_Mat4f_Mat1i, (bp::arg("inst_Mat4f")));
        bp::def("asMat2i", &cvt_Mat4f_Mat2i, (bp::arg("inst_Mat4f")));
        bp::def("asMat3i", &cvt_Mat4f_Mat3i, (bp::arg("inst_Mat4f")));
        bp::def("asMat4i", &cvt_Mat4f_Mat4i, (bp::arg("inst_Mat4f")));
        bp::def("asMat1f", &cvt_Mat4f_Mat1f, (bp::arg("inst_Mat4f")));
        bp::def("asMat2f", &cvt_Mat4f_Mat2f, (bp::arg("inst_Mat4f")));
        bp::def("asMat3f", &cvt_Mat4f_Mat3f, (bp::arg("inst_Mat4f")));
        bp::def("asMat1d", &cvt_Mat4f_Mat1d, (bp::arg("inst_Mat4f")));
        bp::def("asMat2d", &cvt_Mat4f_Mat2d, (bp::arg("inst_Mat4f")));
        bp::def("asMat3d", &cvt_Mat4f_Mat3d, (bp::arg("inst_Mat4f")));
        bp::def("asMat4d", &cvt_Mat4f_Mat4d, (bp::arg("inst_Mat4f")));
        bp::def("asMat1b", &cvt_Mat1d_Mat1b, (bp::arg("inst_Mat1d")));
        bp::def("asMat2b", &cvt_Mat1d_Mat2b, (bp::arg("inst_Mat1d")));
        bp::def("asMat3b", &cvt_Mat1d_Mat3b, (bp::arg("inst_Mat1d")));
        bp::def("asMat4b", &cvt_Mat1d_Mat4b, (bp::arg("inst_Mat1d")));
        bp::def("asMat1s", &cvt_Mat1d_Mat1s, (bp::arg("inst_Mat1d")));
        bp::def("asMat2s", &cvt_Mat1d_Mat2s, (bp::arg("inst_Mat1d")));
        bp::def("asMat3s", &cvt_Mat1d_Mat3s, (bp::arg("inst_Mat1d")));
        bp::def("asMat4s", &cvt_Mat1d_Mat4s, (bp::arg("inst_Mat1d")));
        bp::def("asMat1w", &cvt_Mat1d_Mat1w, (bp::arg("inst_Mat1d")));
        bp::def("asMat2w", &cvt_Mat1d_Mat2w, (bp::arg("inst_Mat1d")));
        bp::def("asMat3w", &cvt_Mat1d_Mat3w, (bp::arg("inst_Mat1d")));
        bp::def("asMat4w", &cvt_Mat1d_Mat4w, (bp::arg("inst_Mat1d")));
        bp::def("asMat1i", &cvt_Mat1d_Mat1i, (bp::arg("inst_Mat1d")));
        bp::def("asMat2i", &cvt_Mat1d_Mat2i, (bp::arg("inst_Mat1d")));
        bp::def("asMat3i", &cvt_Mat1d_Mat3i, (bp::arg("inst_Mat1d")));
        bp::def("asMat4i", &cvt_Mat1d_Mat4i, (bp::arg("inst_Mat1d")));
        bp::def("asMat1f", &cvt_Mat1d_Mat1f, (bp::arg("inst_Mat1d")));
        bp::def("asMat2f", &cvt_Mat1d_Mat2f, (bp::arg("inst_Mat1d")));
        bp::def("asMat3f", &cvt_Mat1d_Mat3f, (bp::arg("inst_Mat1d")));
        bp::def("asMat4f", &cvt_Mat1d_Mat4f, (bp::arg("inst_Mat1d")));
        bp::def("asMat2d", &cvt_Mat1d_Mat2d, (bp::arg("inst_Mat1d")));
        bp::def("asMat3d", &cvt_Mat1d_Mat3d, (bp::arg("inst_Mat1d")));
        bp::def("asMat4d", &cvt_Mat1d_Mat4d, (bp::arg("inst_Mat1d")));
        bp::def("asMat1b", &cvt_Mat2d_Mat1b, (bp::arg("inst_Mat2d")));
        bp::def("asMat2b", &cvt_Mat2d_Mat2b, (bp::arg("inst_Mat2d")));
        bp::def("asMat3b", &cvt_Mat2d_Mat3b, (bp::arg("inst_Mat2d")));
        bp::def("asMat4b", &cvt_Mat2d_Mat4b, (bp::arg("inst_Mat2d")));
        bp::def("asMat1s", &cvt_Mat2d_Mat1s, (bp::arg("inst_Mat2d")));
        bp::def("asMat2s", &cvt_Mat2d_Mat2s, (bp::arg("inst_Mat2d")));
        bp::def("asMat3s", &cvt_Mat2d_Mat3s, (bp::arg("inst_Mat2d")));
        bp::def("asMat4s", &cvt_Mat2d_Mat4s, (bp::arg("inst_Mat2d")));
        bp::def("asMat1w", &cvt_Mat2d_Mat1w, (bp::arg("inst_Mat2d")));
        bp::def("asMat2w", &cvt_Mat2d_Mat2w, (bp::arg("inst_Mat2d")));
        bp::def("asMat3w", &cvt_Mat2d_Mat3w, (bp::arg("inst_Mat2d")));
        bp::def("asMat4w", &cvt_Mat2d_Mat4w, (bp::arg("inst_Mat2d")));
        bp::def("asMat1i", &cvt_Mat2d_Mat1i, (bp::arg("inst_Mat2d")));
        bp::def("asMat2i", &cvt_Mat2d_Mat2i, (bp::arg("inst_Mat2d")));
        bp::def("asMat3i", &cvt_Mat2d_Mat3i, (bp::arg("inst_Mat2d")));
        bp::def("asMat4i", &cvt_Mat2d_Mat4i, (bp::arg("inst_Mat2d")));
        bp::def("asMat1f", &cvt_Mat2d_Mat1f, (bp::arg("inst_Mat2d")));
        bp::def("asMat2f", &cvt_Mat2d_Mat2f, (bp::arg("inst_Mat2d")));
        bp::def("asMat3f", &cvt_Mat2d_Mat3f, (bp::arg("inst_Mat2d")));
        bp::def("asMat4f", &cvt_Mat2d_Mat4f, (bp::arg("inst_Mat2d")));
        bp::def("asMat1d", &cvt_Mat2d_Mat1d, (bp::arg("inst_Mat2d")));
        bp::def("asMat3d", &cvt_Mat2d_Mat3d, (bp::arg("inst_Mat2d")));
        bp::def("asMat4d", &cvt_Mat2d_Mat4d, (bp::arg("inst_Mat2d")));
        bp::def("asMat1b", &cvt_Mat3d_Mat1b, (bp::arg("inst_Mat3d")));
        bp::def("asMat2b", &cvt_Mat3d_Mat2b, (bp::arg("inst_Mat3d")));
        bp::def("asMat3b", &cvt_Mat3d_Mat3b, (bp::arg("inst_Mat3d")));
        bp::def("asMat4b", &cvt_Mat3d_Mat4b, (bp::arg("inst_Mat3d")));
        bp::def("asMat1s", &cvt_Mat3d_Mat1s, (bp::arg("inst_Mat3d")));
        bp::def("asMat2s", &cvt_Mat3d_Mat2s, (bp::arg("inst_Mat3d")));
        bp::def("asMat3s", &cvt_Mat3d_Mat3s, (bp::arg("inst_Mat3d")));
        bp::def("asMat4s", &cvt_Mat3d_Mat4s, (bp::arg("inst_Mat3d")));
        bp::def("asMat1w", &cvt_Mat3d_Mat1w, (bp::arg("inst_Mat3d")));
        bp::def("asMat2w", &cvt_Mat3d_Mat2w, (bp::arg("inst_Mat3d")));
        bp::def("asMat3w", &cvt_Mat3d_Mat3w, (bp::arg("inst_Mat3d")));
        bp::def("asMat4w", &cvt_Mat3d_Mat4w, (bp::arg("inst_Mat3d")));
        bp::def("asMat1i", &cvt_Mat3d_Mat1i, (bp::arg("inst_Mat3d")));
        bp::def("asMat2i", &cvt_Mat3d_Mat2i, (bp::arg("inst_Mat3d")));
        bp::def("asMat3i", &cvt_Mat3d_Mat3i, (bp::arg("inst_Mat3d")));
        bp::def("asMat4i", &cvt_Mat3d_Mat4i, (bp::arg("inst_Mat3d")));
        bp::def("asMat1f", &cvt_Mat3d_Mat1f, (bp::arg("inst_Mat3d")));
        bp::def("asMat2f", &cvt_Mat3d_Mat2f, (bp::arg("inst_Mat3d")));
        bp::def("asMat3f", &cvt_Mat3d_Mat3f, (bp::arg("inst_Mat3d")));
        bp::def("asMat4f", &cvt_Mat3d_Mat4f, (bp::arg("inst_Mat3d")));
        bp::def("asMat1d", &cvt_Mat3d_Mat1d, (bp::arg("inst_Mat3d")));
        bp::def("asMat2d", &cvt_Mat3d_Mat2d, (bp::arg("inst_Mat3d")));
        bp::def("asMat4d", &cvt_Mat3d_Mat4d, (bp::arg("inst_Mat3d")));
        bp::def("asMat1b", &cvt_Mat4d_Mat1b, (bp::arg("inst_Mat4d")));
        bp::def("asMat2b", &cvt_Mat4d_Mat2b, (bp::arg("inst_Mat4d")));
        bp::def("asMat3b", &cvt_Mat4d_Mat3b, (bp::arg("inst_Mat4d")));
        bp::def("asMat4b", &cvt_Mat4d_Mat4b, (bp::arg("inst_Mat4d")));
        bp::def("asMat1s", &cvt_Mat4d_Mat1s, (bp::arg("inst_Mat4d")));
        bp::def("asMat2s", &cvt_Mat4d_Mat2s, (bp::arg("inst_Mat4d")));
        bp::def("asMat3s", &cvt_Mat4d_Mat3s, (bp::arg("inst_Mat4d")));
        bp::def("asMat4s", &cvt_Mat4d_Mat4s, (bp::arg("inst_Mat4d")));
        bp::def("asMat1w", &cvt_Mat4d_Mat1w, (bp::arg("inst_Mat4d")));
        bp::def("asMat2w", &cvt_Mat4d_Mat2w, (bp::arg("inst_Mat4d")));
        bp::def("asMat3w", &cvt_Mat4d_Mat3w, (bp::arg("inst_Mat4d")));
        bp::def("asMat4w", &cvt_Mat4d_Mat4w, (bp::arg("inst_Mat4d")));
        bp::def("asMat1i", &cvt_Mat4d_Mat1i, (bp::arg("inst_Mat4d")));
        bp::def("asMat2i", &cvt_Mat4d_Mat2i, (bp::arg("inst_Mat4d")));
        bp::def("asMat3i", &cvt_Mat4d_Mat3i, (bp::arg("inst_Mat4d")));
        bp::def("asMat4i", &cvt_Mat4d_Mat4i, (bp::arg("inst_Mat4d")));
        bp::def("asMat1f", &cvt_Mat4d_Mat1f, (bp::arg("inst_Mat4d")));
        bp::def("asMat2f", &cvt_Mat4d_Mat2f, (bp::arg("inst_Mat4d")));
        bp::def("asMat3f", &cvt_Mat4d_Mat3f, (bp::arg("inst_Mat4d")));
        bp::def("asMat4f", &cvt_Mat4d_Mat4f, (bp::arg("inst_Mat4d")));
        bp::def("asMat1d", &cvt_Mat4d_Mat1d, (bp::arg("inst_Mat4d")));
        bp::def("asMat2d", &cvt_Mat4d_Mat2d, (bp::arg("inst_Mat4d")));
        bp::def("asMat3d", &cvt_Mat4d_Mat3d, (bp::arg("inst_Mat4d")));;
    }

}
